@@ -33,7 +33,8 @@
  *   need to be considered and counted.
  * ***************************************************************************** */
 
-TestEkosCaptureCount::TestEkosCaptureCount(QObject *parent) : QObject(parent) {
+TestEkosCaptureCount::TestEkosCaptureCount(QObject *parent) : QObject(parent)
+{
     m_CaptureHelper = new TestEkosCaptureHelper();
 }
 
@@ -99,13 +100,16 @@ void TestEkosCaptureCount::testSchedulerCapture_data()
     prepareTestData(0.1, "Luminance:3,Red:1,Green:1,Blue:1,Luminance:2", "Luminance:15,Red:1,Green:2,Blue:2", "Red:1", 2);
     prepareTestData(0.1, "Luminance:3,Red:1,Green:1,Blue:1,Luminance:2", "Luminance:15,Red:2,Green:3,Blue:3", "Red:1", 3);
     prepareTestData(0.1, "Luminance:3,Red:1,Green:1,Blue:1,Luminance:2", "Luminance:15,Red:3,Green:3,Blue:2", "Blue:1", 3);
-    prepareTestData(0.1, "Luminance:3,Red:1,Green:1,Blue:1,Luminance:2", "Luminance:5,Red:1,Green:1,Blue:1", "Luminance:10,Red:2,Green:2,Blue:2", 3);
-    prepareTestData(0.1, "Luminance:3,Red:1,Green:1,Blue:1,Luminance:2", "Luminance:2,Red:1,Green:1,Blue:1", "Luminance:13,Red:2,Green:2,Blue:2", 3);
+    prepareTestData(0.1, "Luminance:3,Red:1,Green:1,Blue:1,Luminance:2", "Luminance:5,Red:1,Green:1,Blue:1",
+                    "Luminance:10,Red:2,Green:2,Blue:2", 3);
+    prepareTestData(0.1, "Luminance:3,Red:1,Green:1,Blue:1,Luminance:2", "Luminance:2,Red:1,Green:1,Blue:1",
+                    "Luminance:13,Red:2,Green:2,Blue:2", 3);
 #else
     prepareTestData(0.1, "Red:2,Green:2,Blue:2", "Red:2,Green:1,Blue:2", "Green:1");
     prepareTestData(0.1, "Red:1,Green:1,Blue:1,Red:1,Green:1,Blue:1", "Red:2,Green:1,Blue:2", "Green:1");
     prepareTestData(0.1, "Luminance:3,Red:1,Green:1,Blue:1,Luminance:2", "Luminance:4,Green:1,Blue:1", "Luminance:1,Red:1");
-    prepareTestData(0.1, "Luminance:3,Red:1,Green:1,Blue:1,Luminance:2", "Luminance:5,Red:1,Green:1,Blue:1", "Luminance:10,Red:2,Green:2,Blue:2", 3);
+    prepareTestData(0.1, "Luminance:3,Red:1,Green:1,Blue:1,Luminance:2", "Luminance:5,Red:1,Green:1,Blue:1",
+                    "Luminance:10,Red:2,Green:2,Blue:2", 3);
 #endif
 }
 
@@ -151,8 +155,10 @@ void TestEkosCaptureCount::cleanupTestCase()
 
 void TestEkosCaptureCount::init()
 {
-    connect(Ekos::Manager::Instance()->captureModule(), &Ekos::Capture::captureComplete, this, &TestEkosCaptureCount::captureComplete);
-    connect(Ekos::Manager::Instance()->schedulerModule(), &Ekos::Scheduler::newStatus, this, &TestEkosCaptureCount::schedulerStateChanged);
+    connect(Ekos::Manager::Instance()->captureModule(), &Ekos::Capture::captureComplete, this,
+            &TestEkosCaptureCount::captureComplete);
+    connect(Ekos::Manager::Instance()->schedulerModule(), &Ekos::Scheduler::newStatus, this,
+            &TestEkosCaptureCount::schedulerStateChanged);
     QStandardPaths::setTestModeEnabled(true);
     // clear image directory
     QVERIFY(m_CaptureHelper->getImageLocation()->removeRecursively());
@@ -162,8 +168,10 @@ void TestEkosCaptureCount::cleanup()
 {
     QVERIFY(m_CaptureHelper->stopCapturing());
 
-    disconnect(Ekos::Manager::Instance()->schedulerModule(), &Ekos::Scheduler::newStatus, this, &TestEkosCaptureCount::schedulerStateChanged);
-    disconnect(Ekos::Manager::Instance()->captureModule(), &Ekos::Capture::captureComplete, this, &TestEkosCaptureCount::captureComplete);
+    disconnect(Ekos::Manager::Instance()->schedulerModule(), &Ekos::Scheduler::newStatus, this,
+               &TestEkosCaptureCount::schedulerStateChanged);
+    disconnect(Ekos::Manager::Instance()->captureModule(), &Ekos::Capture::captureComplete, this,
+               &TestEkosCaptureCount::captureComplete);
 
     // clean up capture page
     Ekos::Manager::Instance()->captureModule()->clearSequenceQueue();
@@ -188,7 +196,8 @@ bool TestEkosCaptureCount::checkCapturedFrames()
     for (QMap<QString, int>::iterator it = m_expectedImages.begin(); it != m_expectedImages.end(); ++it)
         if (it.value() != 0)
         {
-            QWARN(QString("Capture count for signature %1 does not match: %2 frames too %3 captured.").arg(it.key()).arg(abs(it.value())).arg(it.value() < 0 ? "much" : "few").toStdString().c_str());
+            QWARN(QString("Capture count for signature %1 does not match: %2 frames too %3 captured.").arg(it.key()).arg(abs(
+                        it.value())).arg(it.value() < 0 ? "much" : "few").toStdString().c_str());
             success = false;
         }
 
@@ -200,8 +209,8 @@ bool TestEkosCaptureCount::executeCapturing()
 
     // calculate frame counts
     int framesCount = 0;
-    for(int value: m_expectedImages.values())
-            framesCount += value;
+    for(int value : m_expectedImages.values())
+        framesCount += value;
 
     // capture
     KWRAP_SUB(QVERIFY(m_CaptureHelper->startCapturing(framesCount > 0)));
@@ -273,7 +282,8 @@ bool TestEkosCaptureCount::prepareScheduledCapture(SchedulerJob::CompletionCondi
     // step 1: create the frames due to the captured frames map
     if (capturedFramesMap != "")
     {
-        KVERIFY_SUB(m_CaptureHelper->fillCaptureSequences(target, capturedFramesMap, exptime, m_CaptureHelper->getImageLocation()->filePath(target)));
+        KVERIFY_SUB(m_CaptureHelper->fillCaptureSequences(target, capturedFramesMap, exptime,
+                    m_CaptureHelper->getImageLocation()->filePath(target)));
         KVERIFY_SUB(fillCapturedFramesMap(""));
         KVERIFY_SUB(setExpectedFrames(capturedFramesMap));
 
@@ -305,8 +315,9 @@ bool TestEkosCaptureCount::prepareScheduledCapture(SchedulerJob::CompletionCondi
     return true;
 }
 
-bool TestEkosCaptureCount::setupScheduler(QString sequenceFile, QString sequence, QString capturedFramesMap, SchedulerJob::CompletionCondition completionCondition,
-                                          int iterations, bool rememberJobProgress, double exptime)
+bool TestEkosCaptureCount::setupScheduler(QString sequenceFile, QString sequence, QString capturedFramesMap,
+        SchedulerJob::CompletionCondition completionCondition,
+        int iterations, bool rememberJobProgress, double exptime)
 {
     Ekos::Scheduler *scheduler = Ekos::Manager::Instance()->schedulerModule();
     KWRAP_SUB(KTRY_SWITCH_TO_MODULE_WITH_TIMEOUT(scheduler, 1000));
@@ -329,32 +340,35 @@ bool TestEkosCaptureCount::setupScheduler(QString sequenceFile, QString sequence
     Options::setStopEkosAfterShutdown(false);
 
     // set the completion condition
-    switch (completionCondition) {
-    case SchedulerJob::FINISH_REPEAT:
-        // repeat the job for a fixed amount
-        KTRY_SET_RADIOBUTTON_SUB(scheduler, repeatCompletionR, true);
-        KTRY_SET_SPINBOX_SUB(scheduler, repeatsSpin, iterations);
-        break;
-    case SchedulerJob::FINISH_LOOP:
-        KTRY_SET_RADIOBUTTON_SUB(scheduler, loopCompletionR, true);
-        break;
-    default:
-        QWARN(QString("Unsupported completion condition %1!").arg(completionCondition).toStdString().c_str());
-        return false;
-        break;
+    switch (completionCondition)
+    {
+        case SchedulerJob::FINISH_REPEAT:
+            // repeat the job for a fixed amount
+            KTRY_SET_RADIOBUTTON_SUB(scheduler, repeatCompletionR, true);
+            KTRY_SET_SPINBOX_SUB(scheduler, repeatsSpin, iterations);
+            break;
+        case SchedulerJob::FINISH_LOOP:
+            KTRY_SET_RADIOBUTTON_SUB(scheduler, loopCompletionR, true);
+            break;
+        default:
+            QWARN(QString("Unsupported completion condition %1!").arg(completionCondition).toStdString().c_str());
+            return false;
+            break;
     }
     // add scheduler job
     KTRY_CLICK_SUB(scheduler, addToQueueB);
 
     // verify the displayed capture counts
-    KVERIFY_SUB(verifySchedulerCounting(sequence, capturedFramesMap, completionCondition, iterations, rememberJobProgress, exptime));
+    KVERIFY_SUB(verifySchedulerCounting(sequence, capturedFramesMap, completionCondition, iterations, rememberJobProgress,
+                                        exptime));
 
     // everything worked as expected
     return true;
 }
 
-bool TestEkosCaptureCount::verifySchedulerCounting(QString sequence, QString capturedFramesMap, SchedulerJob::CompletionCondition completionCondition,
-                                                   int iterations, bool rememberJobProgress, double exptime)
+bool TestEkosCaptureCount::verifySchedulerCounting(QString sequence, QString capturedFramesMap,
+        SchedulerJob::CompletionCondition completionCondition,
+        int iterations, bool rememberJobProgress, double exptime)
 {
     Ekos::Scheduler *scheduler = Ekos::Manager::Instance()->schedulerModule();
     KTRY_GADGET_SUB(scheduler, QTableWidget, queueTable);
@@ -371,7 +385,8 @@ bool TestEkosCaptureCount::verifySchedulerCounting(QString sequence, QString cap
         total = displayedCounts.right(displayedCounts.length() - displayedCounts.indexOf("/") - 1).toInt();
         total_repeat_expected = totalCount(sequence) * iterations;
         KVERIFY2_SUB(total == total_repeat_expected,
-                     QString("Scheduler job table shows %1 expected frames instead of %2.").arg(total).arg(total_repeat_expected).toStdString().c_str());
+                     QString("Scheduler job table shows %1 expected frames instead of %2.").arg(total).arg(
+                         total_repeat_expected).toStdString().c_str());
     }
 
     // check display of already captured
@@ -389,22 +404,25 @@ bool TestEkosCaptureCount::verifySchedulerCounting(QString sequence, QString cap
     }
     // execute the check
     KVERIFY2_SUB(captured == captured_expected,
-                 QString("Scheduler job table shows %1 captured frames instead of %2.").arg(captured).arg(captured_expected).toStdString().c_str());
+                 QString("Scheduler job table shows %1 captured frames instead of %2.").arg(captured).arg(
+                     captured_expected).toStdString().c_str());
 
     // check estimated duration time (only relevant for repeats
     if (completionCondition == SchedulerJob::FINISH_REPEAT)
     {
         QString estimation = queueTable->item(0, 7)->text();
         QTime estimatedDuration = QTime::fromString(estimation, "HH:mm:ss");
-        int duration = estimatedDuration.second() + 60*estimatedDuration.minute() + 3600*estimatedDuration.hour();
+        int duration = estimatedDuration.second() + 60 * estimatedDuration.minute() + 3600 * estimatedDuration.hour();
         KVERIFY2_SUB(std::fabs((total_repeat_expected - captured_expected)*exptime - duration) <= 1,
-                     QString("Scheduler job table shows %1 seconds expected instead of %2.").arg(duration).arg((total_repeat_expected - captured_expected)*exptime).toStdString().c_str());
+                     QString("Scheduler job table shows %1 seconds expected instead of %2.").arg(duration).arg((
+                                 total_repeat_expected - captured_expected)*exptime).toStdString().c_str());
     }
     // everything worked as expected
     return true;
 }
 
-void TestEkosCaptureCount::prepareTestData(double exptime, QString sequence, QString capturedFramesMap, QString expectedFrames, int iterations)
+void TestEkosCaptureCount::prepareTestData(double exptime, QString sequence, QString capturedFramesMap,
+        QString expectedFrames, int iterations)
 {
 
     QTest::addColumn<double>("exptime");             /*!< exposure time */
@@ -414,10 +432,14 @@ void TestEkosCaptureCount::prepareTestData(double exptime, QString sequence, QSt
     QTest::addColumn<int>("iterations");             /*!< how often should the sequence be repeated */
     QTest::addColumn<bool>("rememberJobProgress");   /*!< "Remember job progress" option selected */
 
-    for (bool remember : {false, true})
-        QTest::newRow(QString("seq=%1, captured=%2, it=%3, remember=%4").arg(sequence).arg(capturedFramesMap).arg(iterations).arg(remember ? "true":"false").toStdString().c_str())
+    for (bool remember :
+            {
+                false, true
+            })
+        QTest::newRow(QString("seq=%1, captured=%2, it=%3, remember=%4").arg(sequence).arg(capturedFramesMap).arg(iterations).arg(
+                          remember ? "true" : "false").toStdString().c_str())
                 << exptime << sequence << capturedFramesMap << expectedFrames << iterations << remember;
- }
+}
 
 bool TestEkosCaptureCount::fillCapturedFramesMap(QString capturedFramesMap)
 {
@@ -427,8 +449,9 @@ bool TestEkosCaptureCount::fillCapturedFramesMap(QString capturedFramesMap)
         {
             KVERIFY_SUB(value.indexOf(":") > -1);
             QString filter = value.left(value.indexOf(":"));
-            int count      = value.right(value.length()-value.indexOf(":")-1).toInt();
-            Ekos::Manager::Instance()->captureModule()->setCapturedFramesMap(m_CaptureHelper->calculateSignature(target, filter), count);
+            int count      = value.right(value.length() - value.indexOf(":") - 1).toInt();
+            Ekos::Manager::Instance()->captureModule()->setCapturedFramesMap(m_CaptureHelper->calculateSignature(target, filter),
+                    count);
         }
     }
 
@@ -443,7 +466,7 @@ bool TestEkosCaptureCount::setExpectedFrames(QString expectedFrames)
         {
             KVERIFY_SUB(value.indexOf(":") > -1);
             QString filter = value.left(value.indexOf(":"));
-            int count      = value.right(value.length()-value.indexOf(":")-1).toInt();
+            int count      = value.right(value.length() - value.indexOf(":") - 1).toInt();
             if (m_expectedImages.contains(filter))
                 m_expectedImages[filter] += count;
             else
@@ -463,7 +486,7 @@ int TestEkosCaptureCount::totalCount(QString sequence)
 
     int total = 0;
     for (QString value : sequence.split(","))
-        total += value.right(value.length()-value.indexOf(":")-1).toInt();
+        total += value.right(value.length() - value.indexOf(":") - 1).toInt();
 
     return total;
 }
@@ -479,7 +502,7 @@ QMap<QString, uint16_t> TestEkosCaptureCount::framesMap(QString sequence)
     for (QString value : sequence.split(","))
     {
         QString filter = value.left(value.indexOf(":"));
-        int count      = value.right(value.length()-value.indexOf(":")-1).toInt();
+        int count      = value.right(value.length() - value.indexOf(":") - 1).toInt();
         if (result.contains(filter))
             result[filter] += count;
         else
@@ -494,12 +517,9 @@ QMap<QString, uint16_t> TestEkosCaptureCount::framesMap(QString sequence)
  *
  * ********************************************************************************* */
 
-void TestEkosCaptureCount::captureComplete(const QString &filename, double exposureSeconds, const QString &filter, double hfr)
+void TestEkosCaptureCount::captureComplete(const QVariantMap &metadata)
 {
-    Q_UNUSED(filename);
-    Q_UNUSED(exposureSeconds);
-    Q_UNUSED(hfr);
-
+    auto filter = metadata["filter"].toString();
     // reduce the for the job's signature the number of expected images
     m_expectedImages.insert(filter, m_expectedImages.value(filter, 0) - 1);
 }
