@@ -236,6 +236,15 @@ bool KSUserDB::Initialize()
             qCWarning(KSTARS) << query.lastError();
     }
 
+    // Add scripts to profile
+    if (currentDBVersion < 310)
+    {
+        QSqlQuery query(m_UserDB);
+        QString columnQuery = QString("ALTER TABLE profile ADD COLUMN scripts TEXT DEFAULT NULL");
+        if (!query.exec(columnQuery))
+            qCWarning(KSTARS) << query.lastError();
+    }
+
     m_UserDB.close();
     return true;
 }
@@ -355,7 +364,7 @@ bool KSUserDB::RebuildDB()
                   "TEXT, port INTEGER, city TEXT, province TEXT, country TEXT, indiwebmanagerport INTEGER DEFAULT "
                   "NULL, autoconnect INTEGER DEFAULT 1, guidertype INTEGER DEFAULT 0, guiderhost TEXT, guiderport INTEGER,"
                   "primaryscope INTEGER DEFAULT 0, guidescope INTEGER DEFAULT 0, indihub INTEGER DEFAULT 0,"
-                  "portselector INTEGER DEFAULT 1, remotedrivers TEXT DEFAULT NULL)");
+                  "portselector INTEGER DEFAULT 1, remotedrivers TEXT DEFAULT NULL, scripts TEXT DEFAULT NULL)");
     tables.append("CREATE TABLE driver (id INTEGER DEFAULT NULL PRIMARY KEY AUTOINCREMENT, label TEXT NOT NULL, role "
                   "TEXT NOT NULL, profile INTEGER NOT NULL, FOREIGN KEY(profile) REFERENCES profile(id))");
     //tables.append("CREATE TABLE custom_driver (id INTEGER DEFAULT NULL PRIMARY KEY AUTOINCREMENT, drivers TEXT NOT NULL, profile INTEGER NOT NULL, FOREIGN KEY(profile) REFERENCES profile(id))");
@@ -1976,6 +1985,10 @@ void KSUserDB::SaveProfile(ProfileInfo *pi)
     if (!query.exec(QString("UPDATE profile SET remotedrivers='%1' WHERE id=%2").arg(pi->remotedrivers).arg(pi->id)))
         qCWarning(KSTARS) << query.executedQuery() << query.lastError().text();
 
+    // Update scripts
+    if (!query.exec(QString("UPDATE profile SET scripts='%1' WHERE id=%2").arg(QString::fromLocal8Bit(pi->scripts)).arg(pi->id)))
+        qCWarning(KSTARS) << query.executedQuery() << query.lastError().text();
+
     QMapIterator<QString, QString> i(pi->drivers);
     while (i.hasNext())
     {
@@ -2036,8 +2049,9 @@ void KSUserDB::GetAllProfiles(QList<std::shared_ptr<ProfileInfo>> &profiles)
 
         pi->remotedrivers = record.value("remotedrivers").toString();
 
+        pi->scripts = record.value("scripts").toByteArray();
+
         GetProfileDrivers(pi.get());
-        //GetProfileCustomDrivers(pi);
 
         profiles.append(pi);
     }
@@ -2076,7 +2090,7 @@ void KSUserDB::GetProfileDrivers(ProfileInfo *pi)
     custom_driver.setTable("driver");
     custom_driver.setFilter("profile=" + QString::number(pi->id));
     if (custom_driver.select() == false)
-        qDebug() << "custom driver select error: " << custom_driver.query().lastQuery() << custom_driver.lastError().text();
+        qDebug() << Q_FUNC_INFO << "custom driver select error: " << custom_driver.query().lastQuery() << custom_driver.lastError().text();
 
     QSqlRecord record = custom_driver.record(0);
     pi->customDrivers   = record.value("drivers").toString();
@@ -2092,7 +2106,7 @@ void KSUserDB::DeleteProfileDrivers(ProfileInfo *pi)
     QSqlQuery query(m_UserDB);
 
     /*if (!query.exec("DELETE FROM custom_driver WHERE profile=" + QString::number(pi->id)))
-        qDebug() << query.lastQuery() << query.lastError().text();*/
+        qDebug() << Q_FUNC_INFO << query.lastQuery() << query.lastError().text();*/
 
     if (!query.exec("DELETE FROM driver WHERE profile=" + QString::number(pi->id)))
         qCWarning(KSTARS) << query.executedQuery() << query.lastError().text();
