@@ -49,12 +49,11 @@ class ProfileInfo
         int indihub { 0 };
         QString remotedrivers;
         QString guiderhost;
+        QByteArray scripts;
         int id { 0 };
         int port { -1 };
         bool autoConnect { false };
         bool portSelector {false};
-        bool isStellarMate { false };
         int INDIWebManagerPort { -1 };
-        // driver[role] = label
         QMap<QString, QString> drivers;
 };
