@@ -557,9 +557,9 @@ void DetailDialog::createPositionTab(const KStarsDateTime &ut, GeoLocation *geo)
     //Replace the decimal point with localized decimal symbol
     sEpoch.replace('.', QLocale().decimalPoint()); // Is this necessary? -- asimha Oct 2016
 
-    /*qDebug() << (selectedObject->deprecess(data->updateNum())).ra0().toHMSString()
+    /*qDebug() << Q_FUNC_INFO << (selectedObject->deprecess(data->updateNum())).ra0().toHMSString()
              << (selectedObject->deprecess(data->updateNum())).dec0().toDMSString();*/
-    //qDebug() << selectedObject->ra().toHMSString() << selectedObject->dec().toDMSString();
+    //qDebug() << Q_FUNC_INFO << selectedObject->ra().toHMSString() << selectedObject->dec().toDMSString();
     Pos->RALabel->setText(i18n("RA (%1):", sEpoch));
     Pos->DecLabel->setText(i18n("DE (%1):", sEpoch));
     Pos->RA->setText(selectedObject->ra().toHMSString(false, true));
@@ -1194,6 +1194,7 @@ void DetailDialog::updateThumbnail()
         //If the image was unset, delete the old image on disk.
         if (tp->imageFound())
         {
+            #if QT_VERSION < QT_VERSION_CHECK(5, 15, 0)
             bool rc = Data->Image->pixmap()->save(fname, "PNG");
             if (rc == false)
             {
@@ -1202,6 +1203,16 @@ void DetailDialog::updateThumbnail()
             }
             else
                 *Thumbnail = *(Data->Image->pixmap());
+            #else
+            bool rc = Data->Image->pixmap(Qt::ReturnByValue).save(fname, "PNG");
+            if (rc == false)
+            {
+                KSNotification::error(i18n("Unable to save image to %1", fname),
+                                      i18n("Save Thumbnail"));
+            }
+            else
+                *Thumbnail = (Data->Image->pixmap(Qt::ReturnByValue));
+            #endif
         }
         else
         {
