@@ -254,6 +254,11 @@ class Align : public QWidget, public Ui::Align
              */
         void syncCCDInfo();
 
+        /**
+         * @brief syncCCDControls Update camera controls like gain, offset, ISO..etc.
+         */
+        void syncCCDControls();
+
         /**
              * @brief Generate arguments we pass to the remote solver.
              */
@@ -529,8 +534,6 @@ class Align : public QWidget, public Ui::Align
         void setCaptureStatus(Ekos::CaptureState newState);
         // Update Mount module status
         void setMountStatus(ISD::Telescope::Status newState);
-        //        void setMountCoords(const QString &ra, const QString &dec, const QString &az,
-        //                            const QString &alt, int pierSide, const QString &ha);
 
         // Align Settings
         QJsonObject getSettings() const;
@@ -539,6 +542,9 @@ class Align : public QWidget, public Ui::Align
         void zoomAlignView();
         void setAlignZoom(double scale);
 
+        // Manual Rotator Dialog
+        void toggleManualRotator(bool toggled);
+
     private slots:
 
         void setDefaultCCD(QString ccd);
@@ -596,15 +602,18 @@ class Align : public QWidget, public Ui::Align
         void newSolution(const QVariantMap &solution);
 
         // This is sent when we load an image in the view
-        void newImage(FITSView *view);
+        void newImage(const QSharedPointer<FITSView> &view);
         // This is sent when the pixmap is updated within the view
-        void newFrame(FITSView *view);
+        void newFrame(const QSharedPointer<FITSView> &view);
         // Send new solver results
         void newSolverResults(double orientation, double ra, double dec, double pixscale);
 
         // Settings
         void settingsUpdated(const QJsonObject &settings);
 
+        // Manual Rotator
+        void manualRotatorChanged(double currentPA, double targetPA, double threshold);
+
     private:
         /**
          * @brief Retrieve the align status indicator
@@ -694,13 +703,6 @@ class Align : public QWidget, public Ui::Align
         void saveNewEffectiveFOV(double newFOVW, double newFOVH);
         QList<QVariantMap> effectiveFOVs;
         void syncFOV();
-        /**
-         * @brief rotationToPositionAngle Convert Astrometry Rotation to Position Angle
-         * @param value Astrometry.net defined rotation (E of N). Because astrometry.net reads images bottom-up
-         * the orientation is always 180 degrees off.
-         * @return Position Angle matching the rotation.
-         */
-        double rotationToPositionAngle(double value);
 
         // We are using calculated FOV now until a more accurate effective FOV is found.
         bool m_EffectiveFOVPending { false };
@@ -721,15 +723,15 @@ class Align : public QWidget, public Ui::Align
         BlindState useBlindPosition {BLIND_IDLE};
 
         // FOV
-        double ccd_hor_pixel { -1 };
-        double ccd_ver_pixel { -1 };
-        double focal_length { -1 };
-        double aperture { -1 };
-        double fov_x { 0 };
-        double fov_y { 0 };
-        double fov_pixscale { 0 };
-        int ccd_width { 0 };
-        int ccd_height { 0 };
+        double m_CameraPixelWidth { -1 };
+        double m_CameraPixelHeight { -1 };
+        double m_TelescopeFocalLength { -1 };
+        double m_TelescopeAperture { -1 };
+        double m_FOVWidth { 0 };
+        double m_FOVHeight { 0 };
+        double m_FOVPixelScale { 0 };
+        uint16_t m_CameraWidth { 0 };
+        uint16_t m_CameraHeight { 0 };
 
         // Keep track of solver results
         double sOrientation { INVALID_VALUE };
@@ -824,7 +826,7 @@ class Align : public QWidget, public Ui::Align
         QTimer m_AlignTimer;
 
         // Align Frame
-        AlignView *alignView { nullptr };
+        QSharedPointer<AlignView> m_AlignView;
 
         // FITS Viewer in case user want to display in it instead of internal view
         QPointer<FITSViewer> fv;
