@@ -12,18 +12,24 @@
 #include <QUuid>
 
 SolverUtils::SolverUtils(const SSolver::Parameters &parameters, double timeoutSeconds) : m_Parameters(parameters),
-    m_Timeout(timeoutSeconds)
+    m_TimeoutMilliseconds(timeoutSeconds * 1000.0)
 {
     connect(&m_Watcher, &QFutureWatcher<bool>::finished, this, &SolverUtils::executeSolver, Qt::UniqueConnection);
     connect(&m_SolverTimer, &QTimer::timeout, this, &SolverUtils::solverTimeout, Qt::UniqueConnection);
 
     m_StellarSolver.reset(new StellarSolver());
-    connect(m_StellarSolver.get(), &StellarSolver::logOutput, this, &SolverUtils::newLog);
+    // connect(m_StellarSolver.get(), &StellarSolver::logOutput, this, &SolverUtils::newLog);
 }
 
 SolverUtils::~SolverUtils()
 {
-
+    disconnect(&m_Watcher, &QFutureWatcher<bool>::finished, this, &SolverUtils::executeSolver);
+    disconnect(&m_SolverTimer, &QTimer::timeout, this, &SolverUtils::solverTimeout);
+    if (m_StellarSolver.get())
+    {
+        // disconnect(m_StellarSolver.get(), &StellarSolver::logOutput, this, &SolverUtils::newLog);
+        disconnect(m_StellarSolver.get(), &StellarSolver::finished, this, &SolverUtils::solverDone);
+    }
 }
 
 void SolverUtils::executeSolver()
@@ -38,6 +44,30 @@ void SolverUtils::runSolver(const QString &filename)
     m_Watcher.setFuture(response);
 }
 
+void SolverUtils::setHealpix(int indexToUse, int healpixToUse)
+{
+    m_IndexToUse = indexToUse;
+    m_HealpixToUse = healpixToUse;
+}
+
+void SolverUtils::abort()
+{
+    if (m_StellarSolver.get()) m_StellarSolver->abort();
+}
+
+bool SolverUtils::isRunning() const
+{
+    if (!m_StellarSolver.get()) return false;
+    return m_StellarSolver->isRunning();
+}
+
+void SolverUtils::getSolutionHealpix(int *indexUsed, int *healpixUsed) const
+{
+    *indexUsed = m_StellarSolver->getSolutionIndexNumber();
+    *healpixUsed = m_StellarSolver->getSolutionHealpix();
+}
+
+
 void SolverUtils::prepareSolver()
 {
     if (m_StellarSolver->isRunning())
@@ -46,8 +76,18 @@ void SolverUtils::prepareSolver()
     m_StellarSolver->loadNewImageBuffer(m_ImageData->getStatistics(), m_ImageData->getImageBuffer());
     m_StellarSolver->setProperty("ExtractorType", Options::solveSextractorType());
     m_StellarSolver->setProperty("SolverType", Options::solverType());
-    connect(m_StellarSolver.get(), &StellarSolver::ready, this, &SolverUtils::solverDone);
-    m_StellarSolver->setIndexFolderPaths(Options::astrometryIndexFolderList());
+    connect(m_StellarSolver.get(), &StellarSolver::finished, this, &SolverUtils::solverDone, Qt::UniqueConnection);
+
+    if (m_IndexToUse >= 0)
+    {
+        // The would only have an effect if Options::solverType() == SOLVER_STELLARSOLVER
+        QStringList indexFiles = StellarSolver::getIndexFiles(
+                                     Options::astrometryIndexFolderList(), m_IndexToUse, m_HealpixToUse);
+        m_StellarSolver->setIndexFilePaths(indexFiles);
+    }
+    else
+        m_StellarSolver->setIndexFolderPaths(Options::astrometryIndexFolderList());
+
     // External program paths
     ExternalProgramPaths externalPaths;
     externalPaths.sextractorBinaryPath = Options::sextractorBinary();
@@ -59,7 +99,10 @@ void SolverUtils::prepareSolver()
 
     //No need for a conf file this way.
     m_StellarSolver->setProperty("AutoGenerateAstroConfig", true);
-    m_StellarSolver->setParameters(m_Parameters);
+
+    auto params = m_Parameters;
+    params.partition = Options::stellarSolverPartition();
+    m_StellarSolver->setParameters(params);
 
     m_TemporaryFilename.clear();
 
@@ -104,14 +147,17 @@ void SolverUtils::prepareSolver()
 
 void SolverUtils::runSolver(const QSharedPointer<FITSData> &data)
 {
+    // Limit the time the solver can run.
+    m_SolverTimer.setSingleShot(true);
+    m_SolverTimer.setInterval(m_TimeoutMilliseconds);
+    m_SolverTimer.start();
+    // Somehow m_SolverTimer's elapsed time can be greater than the interval,
+    // so using this to get more exact times.
+    m_StartTime = QDateTime::currentMSecsSinceEpoch();
+
     m_ImageData = data;
     prepareSolver();
     m_StellarSolver->start();
-
-    // Limit the time the solver can run.
-    m_SolverTimer.setSingleShot(true);
-    m_SolverTimer.setInterval(m_Timeout * 1000);
-    m_SolverTimer.start();
 }
 
 SolverUtils &SolverUtils::useScale(bool useIt, double scaleLowArcsecPerPixel, double scaleHighArcsecPerPixel)
@@ -130,11 +176,9 @@ SolverUtils &SolverUtils::usePosition(bool useIt, double raDegrees, double decDe
     return *this;
 }
 
-SolverUtils &usePosition(bool useIt, double raDegrees, double decDegrees);
-
 void SolverUtils::solverDone()
 {
-    const double elapsed = m_Timeout - m_SolverTimer.remainingTime() / 1000.0;
+    const double elapsed = (QDateTime::currentMSecsSinceEpoch() - m_StartTime) / 1000.0;
     m_SolverTimer.stop();
 
     FITSImage::Solution solution;
@@ -146,17 +190,44 @@ void SolverUtils::solverDone()
     if (!m_TemporaryFilename.isEmpty())
         QFile::remove(m_TemporaryFilename);
     m_TemporaryFilename.clear();
-    m_ImageData.reset();
 }
 
 void SolverUtils::solverTimeout()
 {
     m_SolverTimer.stop();
     FITSImage::Solution empty;
-    emit done(true, false, empty, m_Timeout);
+    emit done(true, false, empty, m_TimeoutMilliseconds / 1000.0);
 
     if (!m_TemporaryFilename.isEmpty())
         QFile::remove(m_TemporaryFilename);
     m_TemporaryFilename.clear();
-    m_ImageData.reset();
+}
+
+double SolverUtils::rotationToPositionAngle(double value)
+{
+    double pa = value + 180;
+    while (pa > 180)
+        pa -= 360;
+    while (pa < -180)
+        pa += 360;
+    return pa;
+}
+
+double SolverUtils::positionAngleToRotation(double value)
+{
+    double rotation = value - 180;
+    while (rotation > 180)
+        rotation -= 360;
+    while (rotation < -180)
+        rotation += 360;
+    return rotation;
+}
+
+double SolverUtils::rangePA(double pa)
+{
+    while (pa > 180)
+        pa -= 360;
+    while (pa < -180)
+        pa += 360;
+    return pa;
 }
