@@ -39,6 +39,7 @@ enum COMMANDS
     NEW_ALIGN_FRAME,
     NEW_NOTIFICATION,
     NEW_TEMPERATURE,
+    NEW_SCHEDULER_STATE,
 
     SET_CLIENT_STATE,
     LOGOUT,
@@ -90,6 +91,7 @@ enum COMMANDS
     MOUNT_SYNC_TARGET,
     MOUNT_GOTO_RADE,
     MOUNT_GOTO_TARGET,
+    MOUNT_GOTO_PIXEL,
     MOUNT_SET_MOTION,
     MOUNT_SET_TRACKING,
     MOUNT_SET_SLEW_RATE,
@@ -144,6 +146,8 @@ enum COMMANDS
     ALIGN_LOAD_AND_SLEW,
     ALIGN_SET_FILE_EXTENSION,
     ALIGN_SET_SETTINGS,
+    ALIGN_MANUAL_ROTATOR_STATUS,
+    ALIGN_MANUAL_ROTATOR_TOGGLE,
 
     // Scheduler
     SCHEDULER_SET_PRIMARY_SETTINGS,
@@ -155,6 +159,9 @@ enum COMMANDS
     SCHEDULER_SET_OBSERVATORY_SHUTDOWN_PROCEDURE,
     SCHEDULER_GET_JOBS,
     SCHEDULER_ADD_JOBS,
+    SCHEDULER_REMOVE_JOBS,
+    SCHEDULER_GET_SETTINGS,
+    SCHEDULER_START_JOB,
 
     // Polar Assistant Helper
     PAH_START,
@@ -167,12 +174,15 @@ enum COMMANDS
     PAH_RESET_VIEW,
     PAH_SLEW_DONE,
     PAH_PAH_SET_ZOOM,
+    PAH_SET_ALGORITHM,
 
     // Options
     OPTION_SET_HIGH_BANDWIDTH,
     OPTION_SET_IMAGE_TRANSFER,
     OPTION_SET_NOTIFICATIONS,
     OPTION_SET_CLOUD_STORAGE,
+    OPTION_SET,
+    OPTION_GET,
 
     // Storage Options
     SET_BLOBS,
@@ -204,6 +214,7 @@ enum COMMANDS
     // Astronomy Library
     ASTRO_GET_ALMANC,
     ASTRO_SEARCH_OBJECTS,
+    ASTRO_GET_OBJECT_INFO,
     ASTRO_GET_OBJECTS_INFO,
     ASTRO_GET_OBJECTS_IMAGE,
     ASTRO_GET_OBJECTS_OBSERVABILITY,
@@ -223,7 +234,7 @@ enum COMMANDS
     DARK_LIBRARY_GET_VIEW_MASTERS,
     DARK_LIBRARY_GET_MASTERS_IMAGE,
     DARK_LIBRARY_CLEAR_MASTERS_ROW,
-    DARK_LIBRARY_SET_DEFECT_FRAME
+    DARK_LIBRARY_SET_DEFECT_FRAME,
 };
 
 static QMap<COMMANDS, QString> const commands =
@@ -253,6 +264,7 @@ static QMap<COMMANDS, QString> const commands =
     {NEW_ALIGN_FRAME, "new_align_frame"},
     {NEW_NOTIFICATION, "new_notification"},
     {NEW_TEMPERATURE, "new_temperature"},
+    {NEW_SCHEDULER_STATE, "new_scheduler_state"},
 
     {SET_CLIENT_STATE, "set_client_state"},
     {LOGOUT, "logout"},
@@ -300,6 +312,7 @@ static QMap<COMMANDS, QString> const commands =
     {MOUNT_SYNC_TARGET, "mount_sync_target"},
     {MOUNT_GOTO_RADE, "mount_goto_rade"},
     {MOUNT_GOTO_TARGET, "mount_goto_target"},
+    {MOUNT_GOTO_PIXEL, "mount_goto_pixel"},
     {MOUNT_SET_MOTION, "mount_set_motion"},
     {MOUNT_SET_TRACKING, "mount_set_tracking"},
     {MOUNT_SET_SLEW_RATE, "mount_set_slew_rate"},
@@ -345,6 +358,9 @@ static QMap<COMMANDS, QString> const commands =
     {SCHEDULER_SET_OBSERVATORY_SHUTDOWN_PROCEDURE, "scheduler_set_observatory_shutdown_procedure"},
     {SCHEDULER_GET_JOBS, "scheduler_get_jobs"},
     {SCHEDULER_ADD_JOBS, "scheduler_add_jobs"},
+    {SCHEDULER_REMOVE_JOBS, "scheduler_remove_jobs"},
+    {SCHEDULER_GET_SETTINGS, "scheduler_get_settings"},
+    {SCHEDULER_START_JOB, "scheduler_start_job"},
 
     {GUIDE_START, "guide_start"},
     {GUIDE_CAPTURE, "guide_capture"},
@@ -359,6 +375,8 @@ static QMap<COMMANDS, QString> const commands =
     {ALIGN_LOAD_AND_SLEW, "align_load_and_slew"},
     {ALIGN_SET_FILE_EXTENSION, "align_set_file_extension"},
     {ALIGN_SET_SETTINGS, "align_set_settings"},
+    {ALIGN_MANUAL_ROTATOR_STATUS, "align_manual_rotator_status"},
+    {ALIGN_MANUAL_ROTATOR_TOGGLE, "align_manual_rotator_toggle"},
 
     {PAH_START, "polar_start"},
     {PAH_STOP, "polar_stop"},
@@ -370,11 +388,14 @@ static QMap<COMMANDS, QString> const commands =
     {PAH_RESET_VIEW, "polar_reset_view"},
     {PAH_SLEW_DONE, "polar_slew_done"},
     {PAH_PAH_SET_ZOOM, "polar_set_zoom"},
+    {PAH_SET_ALGORITHM, "polar_set_algorithm"},
 
     {OPTION_SET_HIGH_BANDWIDTH, "option_set_high_bandwidth"},
     {OPTION_SET_IMAGE_TRANSFER, "option_set_image_transfer"},
     {OPTION_SET_NOTIFICATIONS, "option_set_notifications"},
     {OPTION_SET_CLOUD_STORAGE, "option_set_cloud_storage"},
+    {OPTION_SET, "option_set"},
+    {OPTION_GET, "option_get"},
 
     {SET_BLOBS, "set_blobs"},
 
@@ -400,6 +421,7 @@ static QMap<COMMANDS, QString> const commands =
 
     {ASTRO_GET_ALMANC, "astro_get_almanac"},
     {ASTRO_SEARCH_OBJECTS, "astro_search_objects"},
+    {ASTRO_GET_OBJECT_INFO, "astro_get_object_info"},
     {ASTRO_GET_OBJECTS_INFO, "astro_get_objects_info"},
     {ASTRO_GET_OBJECTS_IMAGE, "astro_get_objects_image"},
     {ASTRO_GET_OBJECTS_OBSERVABILITY, "astro_get_objects_observability"},
