@@ -29,7 +29,6 @@
 
 namespace EkosLive
 {
-
 Message::Message(Ekos::Manager *manager): m_Manager(manager), m_DSOManager(CatalogsDB::dso_db_path())
 {
     connect(&m_WebSocket, &QWebSocket::connected, this, &Message::onConnected);
@@ -187,6 +186,8 @@ void Message::onTextReceived(const QString &message)
         processDialogResponse(payload);
     else if (command.startsWith("option_"))
         processOptionsCommands(command, payload);
+    else if (command.startsWith("scheduler"))
+        processSchedulerCommands(command, payload);
 
     if (m_Manager->getEkosStartingStatus() != Ekos::Success)
         return;
@@ -222,8 +223,6 @@ void Message::onTextReceived(const QString &message)
         processGuideCommands(command, payload);
     else if (command.startsWith("align_"))
         processAlignCommands(command, payload);
-    else if (command.startsWith("scheduler"))
-        processSchedulerCommands(command, payload);
     else if (command.startsWith("polar_"))
         processPolarCommands(command, payload);
     else if (command.startsWith("dome_"))
@@ -710,6 +709,11 @@ void Message::sendFocusSettings(const QJsonObject &settings)
     sendResponse(commands[FOCUS_SET_SETTINGS], settings);
 }
 
+void Message::sendSchedulerSettings(const QJsonObject &settings)
+{
+    sendResponse(commands[SCHEDULER_GET_SETTINGS], settings);
+}
+
 void Message::processGuideCommands(const QString &command, const QJsonObject &payload)
 {
     Ekos::Guide *guide = m_Manager->guideModule();
@@ -733,7 +737,10 @@ void Message::processGuideCommands(const QString &command, const QJsonObject &pa
     else if (command == commands[GUIDE_CLEAR])
         guide->clearCalibration();
     else if (command == commands[GUIDE_SET_SETTINGS])
+    {
         guide->setSettings(payload);
+        sendGuideSettings(m_Manager->guideModule()->getSettings());
+    }
 }
 
 void Message::processFocusCommands(const QString &command, const QJsonObject &payload)
@@ -874,7 +881,41 @@ void Message::processMountCommands(const QString &command, const QJsonObject &pa
             mount->setAutoParkStartup(QTime::fromString(payload["value"].toString()));
         mount->setAutoParkEnabled(enabled);
     }
+    else if (command == commands[MOUNT_GOTO_PIXEL])
+    {
+        const auto camera = payload["camera"].toString();
+        const auto xFactor = payload["x"].toDouble();
+        const auto yFactor = payload["y"].toDouble();
 
+        for(auto &oneDevice : m_Manager->findDevices(KSTARS_CCD))
+        {
+            auto oneCamera = dynamic_cast<ISD::CCD*>(oneDevice);
+            if (!oneCamera || oneCamera->getDeviceName() != camera)
+                continue;
+
+            auto primaryChip = oneCamera->getChip(ISD::CCDChip::PRIMARY_CCD);
+
+            if (!primaryChip)
+                break;
+
+            auto imageData = primaryChip->getImageData();
+            if (!imageData || imageData->hasWCS() == false)
+                break;
+
+            auto x = xFactor * imageData->width();
+            auto y = yFactor * imageData->height();
+
+            QPointF point(x, y);
+            SkyPoint coord;
+            if (imageData->pixelToWCS(point, coord))
+            {
+                // J2000 -> JNow
+                coord.apparentCoord(static_cast<long double>(J2000), KStars::Instance()->data()->ut().djd());
+                mount->gotoTarget(coord);
+                break;
+            }
+        }
+    }
 }
 
 void Message::processDomeCommands(const QString &command, const QJsonObject &payload)
@@ -945,6 +986,10 @@ void Message::processAlignCommands(const QString &command, const QJsonObject &pa
         file.close();
         align->loadAndSlew(file.fileName());
     }
+    else if (command == commands[ALIGN_MANUAL_ROTATOR_TOGGLE])
+    {
+        align->toggleManualRotator(payload["toggled"].toBool());
+    }
 }
 
 void Message::setAlignStatus(Ekos::AlignState newState)
@@ -984,26 +1029,32 @@ void Message::processSchedulerCommands(const QString &command, const QJsonObject
     else if (command == commands[SCHEDULER_SET_JOB_STARTUP_CONDITIONS])
     {
         scheduler->setJobStartupConditions(payload);
+        sendSchedulerSettings(m_Manager->schedulerModule()->getSchedulerSettings());
     }
     else if (command == commands[SCHEDULER_SET_JOB_CONSTRAINTS])
     {
         scheduler->setJobConstraints(payload);
+        sendSchedulerSettings(m_Manager->schedulerModule()->getSchedulerSettings());
     }
     else if (command == commands[SCHEDULER_SET_JOB_COMPLETION_SETTINGS])
     {
         scheduler->setJobCompletionConditions(payload);
+        sendSchedulerSettings(m_Manager->schedulerModule()->getSchedulerSettings());
     }
     else if (command == commands[SCHEDULER_SET_OBSERVATORY_STARTUP_PROCEDURE])
     {
         scheduler->setObservatoryStartupProcedure(payload);
+        sendSchedulerSettings(m_Manager->schedulerModule()->getSchedulerSettings());
     }
     else if (command == commands[SCHEDULER_SET_ABORTED_JOB_MANAGEMENT])
     {
         scheduler->setAbortedJobManagementSettings(payload);
+        sendSchedulerSettings(m_Manager->schedulerModule()->getSchedulerSettings());
     }
     else if (command == commands[SCHEDULER_SET_OBSERVATORY_SHUTDOWN_PROCEDURE])
     {
         scheduler->setObservatoryShutdownProcedure(payload);
+        sendSchedulerSettings(m_Manager->schedulerModule()->getSchedulerSettings());
     }
     else if (command == commands[SCHEDULER_GET_JOBS])
     {
@@ -1013,6 +1064,19 @@ void Message::processSchedulerCommands(const QString &command, const QJsonObject
     {
         scheduler->addJob();
     }
+    else if(command == commands[SCHEDULER_REMOVE_JOBS])
+    {
+        int index = payload["index"].toInt();
+        scheduler->removeOneJob(index);
+    }
+    else if(command == commands[SCHEDULER_GET_SETTINGS])
+    {
+        sendResponse(commands[SCHEDULER_GET_SETTINGS], scheduler->getSchedulerSettings());
+    }
+    else if(command == commands[SCHEDULER_START_JOB])
+    {
+        scheduler->toggleScheduler();
+    }
 
 }
 
@@ -1041,6 +1105,12 @@ void Message::processPolarCommands(const QString &command, const QJsonObject &pa
         paa->setPAHRefreshDuration(payload["value"].toDouble(1));
         paa->startPAHRefreshProcess();
     }
+    else if (command == commands[PAH_SET_ALGORITHM])
+    {
+        auto algorithmCombo = paa->findChild<QComboBox*>("PAHRefreshAlgorithmCombo");
+        if (algorithmCombo)
+            algorithmCombo->setCurrentIndex(static_cast<Ekos::PolarAlignmentAssistant::PAHRefreshAlgorithm>(payload["value"].toInt(1)));
+    }
     else if (command == commands[PAH_RESET_VIEW])
     {
         emit resetPolarView();
@@ -1069,11 +1139,13 @@ void Message::processPolarCommands(const QString &command, const QJsonObject &pa
     }
     else if (command == commands[PAH_SELECT_STAR_DONE])
     {
-        paa->setPAHCorrectionSelectionComplete();
+        // This button was removed from the desktop PAA scheme.
+        // Nothing to do.
+        // TODO: Make sure this works.
     }
     else if (command == commands[PAH_REFRESHING_DONE])
     {
-        paa->setPAHRefreshComplete();
+        paa->stopPAHProcess();
     }
     else if (command == commands[PAH_SLEW_DONE])
     {
@@ -1155,6 +1227,21 @@ void Message::setPolarResults(QLineF correctionVector, double polarError, double
     sendResponse(commands[NEW_POLAR_STATE], polarState);
 }
 
+void Message::setUpdatedErrors(double total, double az, double alt)
+{
+    if (m_isConnected == false || m_Manager->getEkosStartingStatus() != Ekos::Success)
+        return;
+
+    QJsonObject error =
+    {
+        {"updatedError", total},
+        {"updatedAZError", az},
+        {"updatedALTError", alt}
+    };
+
+    sendResponse(commands[NEW_POLAR_STATE], error);
+}
+
 void Message::setPAHEnabled(bool enabled)
 {
     if (m_isConnected == false || m_Manager->getEkosStartingStatus() != Ekos::Success)
@@ -1237,14 +1324,18 @@ void Message::sendProfiles()
 
 void Message::sendSchedulerJobs()
 {
-    QJsonArray jobArray;
-
-    for (const auto &oneJob : m_Manager->schedulerModule()->getJobs())
-        jobArray.append(oneJob->toJson());
-
     QJsonObject jobs =
     {
-        {"jobs", jobArray}
+        {"jobs", m_Manager->schedulerModule()->getJSONJobs()}
+    };
+    sendResponse(commands[SCHEDULER_GET_JOBS], jobs);
+}
+
+void Message::sendSchedulerJobList(QJsonArray jobsList)
+{
+    QJsonObject jobs =
+    {
+        {"jobs", jobsList}
     };
     sendResponse(commands[SCHEDULER_GET_JOBS], jobs);
 }
@@ -1264,6 +1355,29 @@ void Message::setEkosStatingStatus(Ekos::CommunicationStatus status)
 
 void Message::processOptionsCommands(const QString &command, const QJsonObject &payload)
 {
+    if (command == commands[OPTION_SET])
+    {
+        const QJsonArray options = payload["options"].toArray();
+        for (const auto &oneOption : options)
+            Options::self()->setProperty(oneOption["name"].toString().toLatin1(), oneOption["value"].toVariant());
+        return;
+    }
+    else if (command == commands[OPTION_GET])
+    {
+        const QJsonArray options = payload["options"].toArray();
+        QJsonArray result;
+        for (const auto &oneOption : options)
+        {
+            const auto name = oneOption["name"].toString();
+            QVariant value = Options::self()->property(name.toLatin1());
+            QVariantMap map;
+            map["name"] = name;
+            map["value"] = value;
+            result.append(QJsonObject::fromVariantMap(map));
+        }
+        sendResponse(commands[OPTION_GET], result);
+        return;
+    }
     if (command == commands[OPTION_SET_HIGH_BANDWIDTH])
         m_Options[OPTION_SET_HIGH_BANDWIDTH] = payload["value"].toBool(true);
     else if (command == commands[OPTION_SET_IMAGE_TRANSFER])
@@ -1795,6 +1909,37 @@ void Message::processAstronomyCommands(const QString &command, const QJsonObject
 
         sendResponse(commands[ASTRO_SEARCH_OBJECTS], response);
     }
+    else if(command == commands[ASTRO_GET_OBJECT_INFO])
+    {
+        const auto name = payload["object"].toString();
+        QJsonObject info;
+        SkyObject *oneObject = KStarsData::Instance()->skyComposite()->findByName(name, false);
+        if(oneObject)
+        {
+            info =
+            {
+                {"name", name},
+                {"designations", QJsonArray::fromStringList(oneObject->longname().split(", "))},
+                {"magnitude", oneObject->mag()},
+                {"ra0", oneObject->ra0().Hours()},
+                {"de0", oneObject->dec0().Degrees()},
+                {"ra", oneObject->ra().Hours()},
+                {"de", oneObject->dec().Degrees()},
+                {"object", true}
+            };
+            sendResponse(commands[ASTRO_GET_OBJECT_INFO], info);
+        }
+        else
+        {
+            info =
+            {
+                {"name", name},
+                {"object", false},
+            };
+            sendResponse(commands[ASTRO_GET_OBJECT_INFO], info );
+        }
+
+    }
     // Get a list of object based on criteria
     else if (command == commands[ASTRO_GET_OBJECTS_INFO])
     {
@@ -2170,6 +2315,15 @@ void Message::sendEvent(const QString &message, KSNotification::EventType event)
     sendResponse(commands[NEW_NOTIFICATION], newEvent);
 }
 
+void Message::sendManualRotatorStatus(double currentPA, double targetPA, double threshold)
+{
+    if (m_isConnected == false)
+        return;
+
+    QJsonObject request = {{ "currentPA", currentPA}, {"targetPA", targetPA}, {"threshold", threshold}};
+    sendResponse(commands[ALIGN_MANUAL_ROTATOR_STATUS], request);
+}
+
 void Message::setBoundingRect(QRect rect, QSize view, double currentZoom)
 {
     m_BoundingRect = rect;
