@@ -56,6 +56,10 @@ class Message : public QObject
         void sendCaps();
         void sendDrivers();
         void sendDevices();
+        void sendSchedulerJobList(QJsonArray jobsList);
+
+        // Scheduler
+        void sendSchedulerJobs();
 
     signals:
         void connected();
@@ -89,10 +93,14 @@ class Message : public QObject
         // Focus
         void sendFocusSettings(const QJsonObject &settings);
 
+        //Scheduler
+        void sendSchedulerSettings(const QJsonObject &settings);
+
         // Polar
         void setPAHStage(Ekos::PolarAlignmentAssistant::PAHStage stage);
         void setPAHMessage(const QString &message);
         void setPolarResults(QLineF correctionVector, double polarError, double azError, double altError);
+        void setUpdatedErrors(double total, double az, double alt);
         void setPAHEnabled(bool enabled);
         void setBoundingRect(QRect rect, QSize view, double currentZoom);
         // Capture
@@ -120,6 +128,8 @@ class Message : public QObject
         // StellarSolver
         void sendStellarSolverProfiles();
 
+        void sendManualRotatorStatus(double currentPA, double targetPA, double threshold);
+
     private slots:
 
         // Connection
@@ -136,9 +146,6 @@ class Message : public QObject
         void setProfileMapping(const QJsonObject &payload);
         void sendStates();
 
-        // Scheduler
-        void sendSchedulerJobs();
-
         // Capture
         void processCaptureCommands(const QString &command, const QJsonObject &payload);
         void setCapturePresetSettings(const QJsonObject &settings);
