@@ -55,7 +55,7 @@ class Focus : public QWidget, public Ui::Focus
 
         typedef enum { FOCUS_NONE, FOCUS_IN, FOCUS_OUT } FocusDirection;
         typedef enum { FOCUS_MANUAL, FOCUS_AUTO } FocusType;
-        typedef enum { FOCUS_ITERATIVE, FOCUS_POLYNOMIAL, FOCUS_LINEAR } FocusAlgorithm;
+        typedef enum { FOCUS_ITERATIVE, FOCUS_POLYNOMIAL, FOCUS_LINEAR, FOCUS_LINEAR1PASS } FocusAlgorithm;
         //typedef enum { FOCUSER_TEMPERATURE, OBSERVATORY_TEMPERATURE, NO_TEMPERATURE } TemperatureSource;
 
         /** @defgroup FocusDBusInterface Ekos DBus Interface - Focus Module
@@ -264,6 +264,12 @@ class Focus : public QWidget, public Ui::Focus
              */
         Q_SCRIPTABLE bool focusOut(int ms = -1);
 
+        /**
+             * @brief checkFocus Given the minimum required HFR, check focus and calculate HFR. If current HFR exceeds required HFR, start autofocus process, otherwise do nothing.
+             * @param requiredHFR Minimum HFR to trigger autofocus process.
+             */
+        Q_SCRIPTABLE Q_NOREPLY void checkFocus(double requiredHFR);
+
         /** @}*/
 
         /**
@@ -299,6 +305,11 @@ class Focus : public QWidget, public Ui::Focus
              */
         void syncCCDInfo();
 
+        /**
+         * @brief Update camera controls like Gain, ISO, Offset...etc
+         */
+        void syncCCDControls();
+
         /**
              * @brief Check Focuser and make sure information is updated accordingly.
              * @param FocuserNum By default, we check the already selected focuser in the dropdown menu. If FocuserNum is specified, the check is made against this specific focuser in the dropdown menu.
@@ -357,12 +368,6 @@ class Focus : public QWidget, public Ui::Focus
              */
         void processTemperatureSource(INumberVectorProperty *nvp);
 
-        /**
-             * @brief checkFocus Given the minimum required HFR, check focus and calculate HFR. If current HFR exceeds required HFR, start autofocus process, otherwise do nothing.
-             * @param requiredHFR Minimum HFR to trigger autofocus process.
-             */
-        void checkFocus(double requiredHFR);
-
         /**
              * @brief setFocusStatus Upon completion of the focusing process, set its status (fail or pass) and reset focus process to clean state.
              * @param status If true, the focus process finished successfully. Otherwise, it failed.
@@ -457,7 +462,7 @@ class Focus : public QWidget, public Ui::Focus
 
         void suspendGuiding();
         void resumeGuiding();
-        void newImage(FITSView *view);
+        void newImage(const QSharedPointer<FITSView> &view);
         void newStarPixmap(QPixmap &);
         void settingsUpdated(const QJsonObject &settings);
 
@@ -482,6 +487,16 @@ class Focus : public QWidget, public Ui::Focus
           * */
         void newHFRPlotPosition(double pos, double hfr, int pulseDuration, bool plot = true);
 
+        /**
+          * @brief new HFR plot position with sigma
+          * @param pos focuser position with associated error (sigma)
+          * @param hfr measured star HFR value
+          * @param sigma is the standard deviation of star HFRs
+          * @param pulseDuration Pulse duration in ms for relative focusers that only support timers,
+          *        or the number of ticks in a relative or absolute focuser
+          * */
+        void newHFRPlotPositionWithSigma(double pos, double hfr, double sigma, int pulseDuration, bool plot = true);
+
         /**
          * @brief draw the approximating polynomial into the HFR V-graph
          * @param poly pointer to the polynomial approximation
@@ -490,6 +505,14 @@ class Focus : public QWidget, public Ui::Focus
          */
         void drawPolynomial(PolynomialFit *poly, bool isVShape, bool activate, bool plot = true);
 
+        /**
+         * @brief draw the curve into the HFR V-graph
+         * @param poly pointer to the polynomial approximation
+         * @param isVShape has the solution a V shape?
+         * @param activate make the graph visible?
+         */
+        void drawCurve(CurveFitting *curve, bool isVShape, bool activate, bool plot = true);
+
         /**
          * @brief Focus solution with minimal HFR found
          * @param solutionPosition focuser position
@@ -511,6 +534,12 @@ class Focus : public QWidget, public Ui::Focus
          */
         void setTitle(const QString &title, bool plot = true);
 
+        /**
+         * @brief update the title on the focus plot
+         * @param title
+         */
+        void updateTitle(const QString &title, bool plot = true);
+
     private:
 
         QList<SSolver::Parameters> m_StellarSolverProfiles;
@@ -552,12 +581,15 @@ class Focus : public QWidget, public Ui::Focus
         // Linear does plotting differently from the rest.
         void plotLinearFocus();
 
+        // Linear final updates to the curve
+        void plotLinearFinalUpdates();
+
         /** @brief Helper function determining whether the focuser behaves like a position
          *         based one (vs. a timer based)
          */
         bool isPositionBased()
         {
-            return (canAbsMove || canRelMove || (focusAlgorithm == FOCUS_LINEAR));
+            return (canAbsMove || canRelMove || (focusAlgorithm == FOCUS_LINEAR) || (focusAlgorithm == FOCUS_LINEAR1PASS));
         }
         void resetButtons();
         void stop(FocusState completionState = FOCUS_ABORTED);
@@ -577,6 +609,8 @@ class Focus : public QWidget, public Ui::Focus
         // Sets the algorithm and enables/disables various UI inputs.
         void setFocusAlgorithm(FocusAlgorithm algorithm);
 
+        void setCurveFit(CurveFitting::CurveFit curvefit);
+
         // Move the focuser in (negative) or out (positive amount).
         bool changeFocus(int amount);
 
@@ -589,7 +623,8 @@ class Focus : public QWidget, public Ui::Focus
         // and set focuserAdditionalMovement to the extra motion, so that after this motion completes
         // we will then scan back in (back to the originally requested position). This "dance" is done
         // to reduce backlash on such movement changes and so that we've always focused in before capture.
-        int adjustLinearPosition(int position, int newPosition);
+        // For LINEAR1PASS algo use the user-defined backlash value to adjust by
+        int adjustLinearPosition(int position, int newPosition, int backlash);
 
         /**
          * @brief syncTrackingBoxPosition Sync the tracking box to the current selected star center
@@ -670,6 +705,8 @@ class Focus : public QWidget, public Ui::Focus
         StarAlgorithm focusDetection { ALGORITHM_GRADIENT };
         /// Focus Process Algorithm
         FocusAlgorithm focusAlgorithm { FOCUS_ITERATIVE };
+        /// Curve fit, default to Quadratic
+        CurveFitting::CurveFit curveFit { CurveFitting::FOCUS_QUADRATIC };
 
         /*********************
          * HFR Club variables
@@ -733,7 +770,12 @@ class Focus : public QWidget, public Ui::Focus
         bool inAutoFocus { false };
         bool inFocusLoop { false };
         //bool inSequenceFocus { false };
-        bool restartFocus { false };
+        /// Keep track of request to retry or abort an AutoFocus run after focus position has been reset
+        /// RESTART_NONE = normal operation, no restart
+        /// RESTART_NOW = restart the autofocus routine
+        /// RESTART_ABORT = when autofocus has been tried MAXIMUM_RESET_ITERATIONS times, abort the routine
+        typedef enum { RESTART_NONE = 0, RESTART_NOW, RESTART_ABORT } FocusRestartState;
+        FocusRestartState m_RestartState { RESTART_NONE };
         /// Did we reverse direction?
         bool reverseDir { false };
         /// Did the user or the auto selection process finish selecting our focus star?
@@ -754,6 +796,10 @@ class Focus : public QWidget, public Ui::Focus
         bool m_RememberCameraFastExposure = { false };
         // Future Watch
         QFutureWatcher<bool> m_StarFinderWatcher;
+        // R2 as a measure of how well the curve fits the datapoints. Passed to the V-curve graph for display
+        double R2 = 0;
+        // Counter to retry the auto focus run if the R2Limit has not been reached
+        int R2Retries = 0;
 
         /// Autofocus log file info.
         QStringList m_LogText;
@@ -793,7 +839,7 @@ class Focus : public QWidget, public Ui::Focus
         QVector3D rememberStarCenter;
 
         /// Focus Frame
-        FITSView *focusView { nullptr };
+        QSharedPointer<FITSView> m_FocusView;
 
         /// Star Select Timer
         QTimer waitStarSelectTimer;
@@ -811,6 +857,9 @@ class Focus : public QWidget, public Ui::Focus
         /// Polynomial fitting.
         std::unique_ptr<PolynomialFit> polynomialFit;
 
+        // Curve fitting.
+        std::unique_ptr<CurveFitting> curveFitting;
+
         // Capture timers
         QTimer captureTimer;
         QTimer captureTimeout;
