@@ -56,7 +56,7 @@ bool InternalGuider::guide()
     {
         return true;
     }
-    guideFrame->disconnect(this);
+    m_GuideFrame->disconnect(this);
 
     pmath->start();
 
@@ -207,7 +207,7 @@ bool InternalGuider::dither(double pixels)
     // Instead we call findLocalStarPosition() which does the analysis from the image.
     // Unfortunately, processGuiding() will repeat that computation.
     // We currently don't cache it.
-    GuiderUtils::Vector star_position = pmath->findLocalStarPosition(m_ImageData, guideFrame, false);
+    GuiderUtils::Vector star_position = pmath->findLocalStarPosition(m_ImageData, m_GuideFrame, false);
     if (pmath->isStarLost() || (star_position.x == -1) || (star_position.y == -1))
     {
         // If the star position is lost, just lose this iteration.
@@ -499,7 +499,7 @@ bool InternalGuider::calibrate()
 
     calibrationProcess->useCalibration(pmath->getMutableCalibration());
 
-    guideFrame->disconnect(this);
+    m_GuideFrame->disconnect(this);
 
     // Must reset dec swap before we run any calibration procedure!
     emit DESwapChanged(false);
@@ -522,7 +522,7 @@ void InternalGuider::iterateCalibration()
 {
     if (calibrationProcess->inProgress())
     {
-        pmath->performProcessing(GUIDE_CALIBRATING, m_ImageData, guideFrame);
+        pmath->performProcessing(GUIDE_CALIBRATING, m_ImageData, m_GuideFrame);
         if (pmath->isStarLost())
         {
             emit newLog(i18n("Lost track of the guide star. Try increasing the square size or reducing pulse duration."));
@@ -574,9 +574,9 @@ void InternalGuider::iterateCalibration()
     }
 }
 
-void InternalGuider::setGuideView(GuideView *guideView)
+void InternalGuider::setGuideView(const QSharedPointer<GuideView> &guideView)
 {
-    guideFrame = guideView;
+    m_GuideFrame = guideView;
 }
 
 void InternalGuider::setImageData(const QSharedPointer<FITSData> &data)
@@ -601,8 +601,7 @@ void InternalGuider::reset()
 {
     state = GUIDE_IDLE;
 
-    connect(guideFrame, SIGNAL(trackingStarSelected(int, int)), this, SLOT(trackingStarSelected(int, int)),
-            Qt::UniqueConnection);
+    connect(m_GuideFrame.get(), &FITSView::trackingStarSelected, this, &InternalGuider::trackingStarSelected, Qt::UniqueConnection);
     calibrationProcess.reset();
 }
 
@@ -631,6 +630,8 @@ void InternalGuider::setStarPosition(QVector3D &starCenter)
 
 void InternalGuider::trackingStarSelected(int x, int y)
 {
+    Q_UNUSED(x);
+    Q_UNUSED(y);
     /*
 
       Not sure what's going on here--manual star selection for calibration?
@@ -702,7 +703,7 @@ bool InternalGuider::processGuiding()
         m_isFirstFrame = false;
         if (state == GUIDE_GUIDING)
         {
-            GuiderUtils::Vector star_pos = pmath->findLocalStarPosition(m_ImageData, guideFrame, true);
+            GuiderUtils::Vector star_pos = pmath->findLocalStarPosition(m_ImageData, m_GuideFrame, true);
             if (star_pos.x != -1 && star_pos.y != -1)
                 pmath->setTargetPosition(star_pos.x, star_pos.y);
             else
@@ -715,7 +716,7 @@ bool InternalGuider::processGuiding()
     }
 
     if (process)
-        pmath->performProcessing(state, m_ImageData, guideFrame, &guideLog);
+        pmath->performProcessing(state, m_ImageData, m_GuideFrame, &guideLog);
 
     if (state == GUIDE_SUSPENDED)
     {
@@ -821,7 +822,7 @@ bool InternalGuider::processGuiding()
 
 bool InternalGuider::selectAutoStarSEPMultistar()
 {
-    guideFrame->updateFrame();
+    m_GuideFrame->updateFrame();
     m_DitherOrigin = QVector3D(0, 0, 0);
     QVector3D newStarCenter = pmath->selectGuideStar(m_ImageData);
     if (newStarCenter.x() >= 0)
@@ -848,7 +849,7 @@ bool InternalGuider::selectAutoStar()
     QList<Edge *> starCenters;
 
     if (Options::guideAlgorithm() != SEP_THRESHOLD)
-        starCenters = GuideAlgorithms::detectStars(m_ImageData, guideFrame->getTrackingBox());
+        starCenters = GuideAlgorithms::detectStars(m_ImageData, m_GuideFrame->getTrackingBox());
 
     if (starCenters.empty())
     {
@@ -880,8 +881,8 @@ bool InternalGuider::selectAutoStar()
             return a->width > b->width;
         });
 
-        guideFrame->setStarsEnabled(true);
-        guideFrame->updateFrame();
+        m_GuideFrame->setStarsEnabled(true);
+        m_GuideFrame->updateFrame();
     }
 
     int maxX = m_ImageData->width();
