@@ -148,7 +148,7 @@ class Manager : public QDialog, public Ui::Manager
         }
         FITSView *getSummaryPreview()
         {
-            return summaryPreview.get();
+            return m_SummaryView.get();
         }
         FilterManager *getFilterManager()
         {
@@ -157,6 +157,13 @@ class Manager : public QDialog, public Ui::Manager
         QString getCurrentJobName();
         void announceEvent(const QString &message, KSNotification::EventType event);
 
+        /**
+         * @brief activateModule Switch tab to specific module name (i.e. CCD) and raise Ekos screen to focus.
+         * @param name module name CCD, Guide, Focus, Mount, Scheduler, or Observatory.
+         * @param popup if True, show Ekos Manager window in the foreground.
+         */
+        void activateModule(const QString &name, bool popup = false);
+
         /**
          * @brief addProfile Add a new profile to the database.
          * @param profileInfo Collection of profile parameters to include the following:
@@ -395,8 +402,13 @@ class Manager : public QDialog, public Ui::Manager
 
         void processTabChange();
 
-        void processServerTerminated(const QString &host, const QString &port);
-        void processServerStarted(const QString &host, const QString &port);
+        void setServerStarted(const QString &host, int port);
+        void setServerFailed(const QString &host, int port, const QString &message);
+        //void setServerTerminated(const QString &host, int port, const QString &message);
+
+        void setClientStarted(const QString &host, int port);
+        void setClientFailed(const QString &host, int port, const QString &message);
+        void setClientTerminated(const QString &host, int port, const QString &message);
 
         void removeDevice(ISD::GDInterface *);
 
@@ -517,7 +529,7 @@ class Manager : public QDialog, public Ui::Manager
         QList<ISD::GDInterface *> proxyDevices;
 
         // All Managed devices (ie. those explicitly defined in the profile)
-        QMap<DeviceFamily, ISD::GDInterface *> managedDevices;
+        QMultiMap<DeviceFamily, ISD::GDInterface *> managedDevices;
 
         // Smart pointers for the various Ekos Modules
         std::unique_ptr<Capture> captureProcess;
@@ -562,7 +574,7 @@ class Manager : public QDialog, public Ui::Manager
         QTimer m_CountdownTimer;
         QTimer settleTimer;
         // Preview Frame
-        std::unique_ptr<SummaryFITSView> summaryPreview;
+        QSharedPointer<SummaryFITSView> m_SummaryView;
 
         ProfileInfo *currentProfile { nullptr };
         bool profileWizardLaunched { false };
