@@ -218,6 +218,7 @@ Mount::Mount()
 
 Mount::~Mount()
 {
+    autoParkTimer.stop();
     delete(m_Ctxt);
     delete(m_BaseObj);
     delete(currentTargetPosition);
@@ -249,11 +250,12 @@ void Mount::setTelescope(ISD::GDInterface *newTelescope)
     connect(currentTelescope, &ISD::Telescope::newCoords, this, &Mount::updateTelescopeCoords);
     connect(currentTelescope, &ISD::Telescope::slewRateChanged, this, &Mount::slewRateChanged);
     connect(currentTelescope, &ISD::Telescope::pierSideChanged, this, &Mount::pierSideChanged);
-    connect(currentTelescope, &ISD::Telescope::Disconnected, [this]()
+    connect(currentTelescope, &ISD::Telescope::axisReversed, this, &Mount::syncAxisReversed);
+    connect(currentTelescope, &ISD::Telescope::Disconnected, this, [this]()
     {
         m_BaseView->hide();
     });
-    connect(currentTelescope, &ISD::Telescope::newParkStatus, [&](ISD::ParkStatus status)
+    connect(currentTelescope, &ISD::Telescope::newParkStatus, this, [&](ISD::ParkStatus status)
     {
         m_ParkStatus = status;
         emit newParkStatus(status);
@@ -276,8 +278,6 @@ void Mount::setTelescope(ISD::GDInterface *newTelescope)
     if (enableLimitsCheck->isChecked())
         currentTelescope->setAltLimits(minAltLimit->value(), maxAltLimit->value());
 
-
-
     syncTelescopeInfo();
 
     // Send initial status
@@ -401,11 +401,11 @@ void Mount::syncTelescopeInfo()
         trackingGroup->setEnabled(true);
         trackOnB->disconnect();
         trackOffB->disconnect();
-        connect(trackOnB, &QPushButton::clicked, [&]()
+        connect(trackOnB, &QPushButton::clicked, this, [&]()
         {
             currentTelescope->setTrackEnabled(true);
         });
-        connect(trackOffB, &QPushButton::clicked, [&]()
+        connect(trackOffB, &QPushButton::clicked, this, [&]()
         {
             if (KMessageBox::questionYesNo(KStars::Instance(),
                                            i18n("Are you sure you want to turn off mount tracking?"),
@@ -764,6 +764,7 @@ void Mount::paaStageChanged(int stage)
     {
         // deactivate the meridian flip when the first capture is taken
         case PolarAlignmentAssistant::PAH_FIRST_CAPTURE:
+        case PolarAlignmentAssistant::PAH_FIRST_SOLVE:
             if (m_MFStatus != FLIP_INACTIVE)
             {
                 appendLogText(i18n("Meridian flip set inactive during polar alignment."));
@@ -773,12 +774,11 @@ void Mount::paaStageChanged(int stage)
         // activate it when the last rotation is finished or stopped
         // for safety reasons, we add all stages after the last rotation
         case PolarAlignmentAssistant::PAH_THIRD_CAPTURE:
+        case PolarAlignmentAssistant::PAH_THIRD_SOLVE:
         case PolarAlignmentAssistant::PAH_STAR_SELECT:
-        case PolarAlignmentAssistant::PAH_PRE_REFRESH:
         case PolarAlignmentAssistant::PAH_REFRESH:
         case PolarAlignmentAssistant::PAH_POST_REFRESH:
         case PolarAlignmentAssistant::PAH_IDLE:
-        case PolarAlignmentAssistant::PAH_ERROR:
             if (m_MFStatus == FLIP_INACTIVE)
             {
                 appendLogText(i18n("Polar alignment motions finished, meridian flip activated."));
@@ -2016,6 +2016,13 @@ double Mount::meridianFlipValue()
     return meridianFlipTimeBox->value();
 }
 
+void Mount::stopTimers()
+{
+    autoParkTimer.stop();
+    if (currentTelescope)
+        currentTelescope->stopTimers();
+}
+
 void Mount::startParkTimer()
 {
     if (currentTelescope == nullptr || m_ParkStatus == ISD::PARK_UNKNOWN)
@@ -2134,4 +2141,12 @@ QString Mount::pierSideStateString()
             return "Pier Side: Unknown";
     }
 }
+
+void Mount::syncAxisReversed(INDI_EQ_AXIS axis, bool reversed)
+{
+    if (axis == AXIS_RA)
+        m_leftRightCheck->setProperty("checked", reversed);
+    else
+        m_upDownCheck->setProperty("checked", reversed);
+}
 }
