@@ -25,7 +25,7 @@ namespace Ekos
  *@class Mount
  *@short Supports controlling INDI telescope devices including setting/retrieving mount properties, slewing, motion and speed controls, in addition to enforcing altitude limits and parking/unparking.
  *@author Jasem Mutlaq
- *@version 1.4
+ *@version 1.5
  */
 
 class Mount : public QWidget, public Ui::Mount
@@ -51,7 +51,7 @@ class Mount : public QWidget, public Ui::Mount
 
     public:
         Mount();
-        ~Mount();
+        ~Mount() override;
 
         //typedef enum { PARKING_IDLE, PARKING_OK, UNPARKING_OK, PARKING_BUSY, UNPARKING_BUSY, PARKING_ERROR } ParkingStatus;
 
@@ -525,6 +525,20 @@ class Mount : public QWidget, public Ui::Mount
          */
         bool gotoTarget(const SkyPoint &target);
 
+        /**
+         * @brief syncAxisReversed Update Mount Control GUI on the reverse motion toggled state.
+         * @param axis RA (left/right) or DE (up/down)
+         * @param reversed True if reversed, false otherwise.
+         */
+        void syncAxisReversed(INDI_EQ_AXIS axis, bool reversed);
+
+        /**
+         * @brief stopTimers Need to stop update timers when profile is disconnected
+         * but due to timing and race conditions, the timers can trigger an invalid access
+         * to INDI device.
+         */
+        void stopTimers();
+
     private slots:
         void startParkTimer();
         void stopParkTimer();
