@@ -29,6 +29,8 @@ FramingAssistantUI::FramingAssistantUI(): QDialog(KStars::Instance()), ui(new Ui
 
     auto tiles = KStarsData::Instance()->skyComposite()->mosaicComponent()->tiles();
 
+    ui->raBox->setUnits(dmsBox::HOURS);
+
     // Initial optics information is taken from Ekos options
     ui->focalLenSpin->setValue(Options::telescopeFocalLength());
     ui->pixelWSizeSpin->setValue(Options::cameraPixelWidth());
@@ -52,7 +54,7 @@ FramingAssistantUI::FramingAssistantUI(): QDialog(KStars::Instance()), ui(new Ui
 
     if (tiles->operationMode() == MosaicTiles::MODE_OPERATION)
     {
-        m_CenterPoint = *tiles.get();
+        m_CenterPoint = *tiles.data();
     }
     else
     {
@@ -65,8 +67,8 @@ FramingAssistantUI::FramingAssistantUI(): QDialog(KStars::Instance()), ui(new Ui
     }
 
     m_CenterPoint.updateCoordsNow(KStarsData::Instance()->updateNum());
-    ui->raBox->setDMS(m_CenterPoint.ra0().toHMSString());
-    ui->decBox->setDMS(m_CenterPoint.dec0().toDMSString());
+    ui->raBox->show(m_CenterPoint.ra0());
+    ui->decBox->show(m_CenterPoint.dec0());
 
     // Page Navigation
     connect(ui->backToEquipmentB, &QPushButton::clicked, this, [this]()
@@ -128,8 +130,8 @@ FramingAssistantUI::FramingAssistantUI(): QDialog(KStars::Instance()), ui(new Ui
         m_CenterPoint.setRA0(range24(m_CenterPoint.ra0().Hours() + dRA.Hours()));
         m_CenterPoint.setDec0(rangeDec(m_CenterPoint.dec0().Degrees() + dDE.Degrees()));
         m_CenterPoint.updateCoordsNow(KStarsData::Instance()->updateNum());
-        ui->raBox->setDMS(m_CenterPoint.ra0().toHMSString());
-        ui->decBox->setDMS(m_CenterPoint.dec0().toDMSString());
+        ui->raBox->show(m_CenterPoint.ra0());
+        ui->decBox->show(m_CenterPoint.dec0());
         //m_CenterPoint.apparentCoord(static_cast<long double>(J2000), KStars::Instance()->data()->ut().djd());
         m_DebounceTimer->start();
     });
@@ -145,7 +147,11 @@ FramingAssistantUI::FramingAssistantUI(): QDialog(KStars::Instance()), ui(new Ui
             ui->targetEdit->blockSignals(true);
             ui->targetEdit->setText(sanitized);
             ui->targetEdit->blockSignals(false);
-            ui->directoryEdit->setText(QDir::cleanPath(QDir::homePath() + QDir::separator() + sanitized));
+
+            if (m_JobsDirectory.isEmpty())
+                ui->directoryEdit->setText(QDir::cleanPath(QDir::homePath() + QDir::separator() + sanitized));
+            else
+                ui->directoryEdit->setText(m_JobsDirectory + QDir::separator() + sanitized);
 
             ui->createJobsB->setEnabled(!ui->targetEdit->text().isEmpty() && !ui->sequenceEdit->text().isEmpty() &&
                                         !ui->directoryEdit->text().isEmpty());
@@ -164,17 +170,24 @@ FramingAssistantUI::FramingAssistantUI(): QDialog(KStars::Instance()), ui(new Ui
         m_CenterPoint.setDec0(J2000Coords.dec0());
 
         m_CenterPoint.updateCoordsNow(KStarsData::Instance()->updateNum());
-        ui->raBox->setDMS(m_CenterPoint.ra0().toHMSString());
-        ui->decBox->setDMS(m_CenterPoint.dec0().toDMSString());
+        ui->raBox->show(m_CenterPoint.ra0());
+        ui->decBox->show(m_CenterPoint.dec0());
         m_DebounceTimer->start();
     });
 
     // Set initial target on startup
     if (tiles->operationMode() == MosaicTiles::MODE_PLANNING && SkyMap::IsFocused())
     {
-        auto target = sanitize(SkyMap::Instance()->focusObject()->name());
-        ui->targetEdit->setText(target);
-        ui->directoryEdit->setText(QDir::cleanPath(QDir::homePath() + QDir::separator() + target));
+        auto sanitized = sanitize(SkyMap::Instance()->focusObject()->name());
+        if (sanitized != i18n("unnamed"))
+        {
+            ui->targetEdit->setText(sanitized);
+
+            if (m_JobsDirectory.isEmpty())
+                ui->directoryEdit->setText(QDir::cleanPath(QDir::homePath() + QDir::separator() + sanitized));
+            else
+                ui->directoryEdit->setText(m_JobsDirectory + QDir::separator() + sanitized);
+        }
     }
 
     // Update object name
@@ -186,14 +199,18 @@ FramingAssistantUI::FramingAssistantUI(): QDialog(KStars::Instance()), ui(new Ui
             // Remove illegal characters that can be problematic
             sanitized = sanitize(sanitized);
             ui->targetEdit->setText(sanitized);
-            ui->directoryEdit->setText(QDir::cleanPath(QDir::homePath() + QDir::separator() + sanitized));
+
+            if (m_JobsDirectory.isEmpty())
+                ui->directoryEdit->setText(QDir::cleanPath(QDir::homePath() + QDir::separator() + sanitized));
+            else
+                ui->directoryEdit->setText(m_JobsDirectory + QDir::separator() + sanitized);
         }
     });
 
     // Watch for manual changes in ra box
     connect(ui->raBox, &dmsBox::editingFinished, this, [this]
     {
-        m_CenterPoint.setRA0(ui->raBox->createDms(false));
+        m_CenterPoint.setRA0(ui->raBox->createDms());
         m_CenterPoint.updateCoordsNow(KStarsData::Instance()->updateNum());
         m_DebounceTimer->start();
     });
@@ -201,7 +218,7 @@ FramingAssistantUI::FramingAssistantUI(): QDialog(KStars::Instance()), ui(new Ui
     // Watch for manual hanges in de box
     connect(ui->decBox, &dmsBox::editingFinished, this, [this]
     {
-        m_CenterPoint.setDec0(ui->decBox->createDms(true));
+        m_CenterPoint.setDec0(ui->decBox->createDms());
         m_CenterPoint.updateCoordsNow(KStarsData::Instance()->updateNum());
         m_DebounceTimer->start();
     });
@@ -210,10 +227,12 @@ FramingAssistantUI::FramingAssistantUI(): QDialog(KStars::Instance()), ui(new Ui
     connect(ui->selectJobsDirB, &QPushButton::clicked, this, &Ekos::FramingAssistantUI::selectDirectory);
     // Rendering options
     ui->transparencySlider->setValue(Options::mosaicTransparencyLevel());
+    ui->transparencySlider->setEnabled(!Options::mosaicTransparencyAuto());
     tiles->setPainterAlpha(Options::mosaicTransparencyLevel());
     connect(ui->transparencySlider, QOverload<int>::of(&QSlider::valueChanged), this, [&](int v)
     {
         ui->transparencySlider->setToolTip(QString("%1%").arg(v));
+        Options::setMosaicTransparencyLevel(v);
         auto tiles = KStarsData::Instance()->skyComposite()->mosaicComponent()->tiles();
         tiles->setPainterAlpha(v);
         m_DebounceTimer->start();
@@ -223,6 +242,7 @@ FramingAssistantUI::FramingAssistantUI(): QDialog(KStars::Instance()), ui(new Ui
     connect(ui->transparencyAuto, &QCheckBox::toggled, this, [&](bool v)
     {
         ui->transparencySlider->setEnabled(!v);
+        Options::setMosaicTransparencyAuto(v);
         auto tiles = KStarsData::Instance()->skyComposite()->mosaicComponent()->tiles();
         tiles->setPainterAlphaAuto(v);
         if (v)
@@ -352,6 +372,7 @@ void FramingAssistantUI::calculateFOV()
     Options::setCameraPixelHeight(ui->pixelHSizeSpin->value());
     Options::setCameraWidth(ui->cameraWSpin->value());
     Options::setCameraHeight(ui->cameraHSpin->value());
+    Options::setCameraRotation(ui->positionAngleSpin->value());
 
     // Calculate FOV in arcmins
     const auto fov_x = 206264.8062470963552 * ui->cameraWSpin->value() * ui->pixelWSizeSpin->value() / 60000.0 /
@@ -450,16 +471,6 @@ void FramingAssistantUI::constructMosaic()
         return;
 
     auto tiles = KStarsData::Instance()->skyComposite()->mosaicComponent()->tiles();
-
-    // Update PA
-    if (std::abs(tiles->positionAngle() - ui->positionAngleSpin->value()) > 0)
-    {
-        Options::setCameraRotation(ui->positionAngleSpin->value());
-    }
-
-    //    qCDebug(KSTARS_EKOS_SCHEDULER) << "Tile FOV in pixels W:" << ui->cameraWFOVSpin->value() * pixelsPerArcminRA << "H:"
-    //                                   << ui->cameraHFOVSpin->value() * pixelsPerArcminDE;
-
     // Set Basic Metadata
 
     // Center
@@ -483,6 +494,12 @@ void FramingAssistantUI::constructMosaic()
 
 void FramingAssistantUI::fetchINDIInformation()
 {
+    // Block all signals so we can set the values directly.
+    for (auto oneWidget : ui->equipment->children())
+        oneWidget->blockSignals(true);
+    for (auto oneWidget : ui->createGrid->children())
+        oneWidget->blockSignals(true);
+
     QDBusInterface alignInterface("org.kde.kstars",
                                   "/KStars/Ekos/Align",
                                   "org.kde.kstars.Ekos.Align",
@@ -515,16 +532,18 @@ void FramingAssistantUI::fetchINDIInformation()
         QList<double> const values = solutionReply.value();
         if (values[0] > INVALID_VALUE)
         {
-            m_Rotation = values[0] + 180;
-            if (m_Rotation > 180)
-                m_Rotation -= 360.0;
-            if (m_Rotation < -180)
-                m_Rotation += 360.0;
-            ui->positionAngleSpin->setValue(m_Rotation);
+            m_PA = SolverUtils::rotationToPositionAngle(values[0]);
+            ui->positionAngleSpin->setValue(m_PA);
         }
     }
 
     calculateFOV();
+
+    // Restore all signals
+    for (auto oneWidget : ui->equipment->children())
+        oneWidget->blockSignals(false);
+    for (auto oneWidget : ui->createGrid->children())
+        oneWidget->blockSignals(false);
 }
 
 void FramingAssistantUI::rewordStepEvery(int v)
@@ -632,7 +651,9 @@ void FramingAssistantUI::createJobs()
     auto schedulerListFile = QString("%1/%2.esl").arg(outputDirectory, target);
     scheduler->saveScheduler(QUrl::fromLocalFile(schedulerListFile));
     accept();
-    Ekos::Manager::Instance()->raise();
+    Ekos::Manager::Instance()->activateModule(i18n("Scheduler"), true);
+
+
 }
 
 void FramingAssistantUI::setMountState(ISD::Telescope::Status value)
@@ -672,12 +693,24 @@ void FramingAssistantUI::selectSequence()
 
 void FramingAssistantUI::selectDirectory()
 {
-    QString dir = QFileDialog::getExistingDirectory(Ekos::Manager::Instance(), i18nc("@title:window", "Select Jobs Directory"),
-                  QDir::homePath());
+    m_JobsDirectory = QFileDialog::getExistingDirectory(Ekos::Manager::Instance(), i18nc("@title:window", "Select Jobs Directory"),
+                      QDir::homePath());
 
-    if (!dir.isEmpty())
+    if (!m_JobsDirectory.isEmpty())
     {
-        ui->directoryEdit->setText(dir);
+        // If we already have a target specified, then append it to directory path.
+        QString sanitized = ui->targetEdit->text();
+        if (sanitized.isEmpty() == false && sanitized != i18n("unnamed"))
+        {
+            // Remove illegal characters that can be problematic
+            sanitized = sanitize(sanitized);
+            ui->directoryEdit->setText(m_JobsDirectory + QDir::separator() + sanitized);
+
+        }
+        else
+            ui->directoryEdit->setText(m_JobsDirectory);
+
+
         ui->createJobsB->setEnabled(!ui->targetEdit->text().isEmpty() && !ui->sequenceEdit->text().isEmpty() &&
                                     !ui->directoryEdit->text().isEmpty());
     }
