@@ -34,11 +34,15 @@ void GreedyScheduler::setParams(bool restartImmediately, bool restartQueue,
     setErrorDelaySeconds(errorHandlingDelay);
 }
 
-QList<SchedulerJob *> GreedyScheduler::scheduleJobs(QList<SchedulerJob *> &jobs,
+QList<SchedulerJob *> GreedyScheduler::scheduleJobs(const QList<SchedulerJob *> &jobs,
         const QDateTime &now,
         const QMap<QString, uint16_t> &capturedFramesCount,
         Scheduler *scheduler)
 {
+    for (auto job : jobs)
+        job->clearCache();
+
+    SchedulerJob::enableGraphicsUpdates(false);
     QDateTime when;
     QElapsedTimer timer;
     timer.start();
@@ -48,7 +52,7 @@ QList<SchedulerJob *> GreedyScheduler::scheduleJobs(QList<SchedulerJob *> &jobs,
     QList<SchedulerJob *> sortedJobs =
         prepareJobsForEvaluation(jobs, now, capturedFramesCount, scheduler);
 
-    scheduledJob = selectNextJob(sortedJobs, now, nullptr, true, &when);
+    scheduledJob = selectNextJob(sortedJobs, now, nullptr, true, &when, nullptr, nullptr, &capturedFramesCount);
     auto schedule = getSchedule();
     if (!schedule.empty())
     {
@@ -57,8 +61,8 @@ QList<SchedulerJob *> GreedyScheduler::scheduleJobs(QList<SchedulerJob *> &jobs,
         // is more important than the log file (where we can invert when debugging).
         for (int i = schedule.size() - 1; i >= 0; i--)
             scheduler->appendLogText(GreedyScheduler::jobScheduleString(schedule[i]));
-        scheduler->appendLogText(QString("Greedy Scheduler plan for the next 48 hours starting %1 (%2)s:").arg(now.toString()).arg(
-                                     timer.elapsed() / 1000.0));
+        scheduler->appendLogText(QString("Greedy Scheduler plan for the next 48 hours starting %1 (%2)s:")
+                                 .arg(now.toString()).arg(timer.elapsed() / 1000.0));
     }
     else scheduler->appendLogText(QString("Greedy Scheduler: empty plan (%1s)").arg(timer.elapsed() / 1000.0));
     if (scheduledJob != nullptr)
@@ -71,10 +75,20 @@ QList<SchedulerJob *> GreedyScheduler::scheduleJobs(QList<SchedulerJob *> &jobs,
         foreach (auto job, sortedJobs)
             job->updateJobCells();
     }
+    // The graphics would get updated many times during scheduling, which can
+    // cause significant cpu usage. No need for that, so we turn off updates
+    // at the start of this method, and then update all jobs once here.
+    SchedulerJob::enableGraphicsUpdates(true);
+    for (auto job : sortedJobs)
+    {
+        job->updateJobCells();
+        job->clearCache();
+    }
+
     return sortedJobs;
 }
 
-bool GreedyScheduler::checkJob(QList<SchedulerJob *> &jobs,
+bool GreedyScheduler::checkJob(const QList<SchedulerJob *> &jobs,
                                const QDateTime &now,
                                SchedulerJob *currentJob)
 {
@@ -95,11 +109,10 @@ bool GreedyScheduler::checkJob(QList<SchedulerJob *> &jobs,
 }
 
 QList<SchedulerJob *> GreedyScheduler::prepareJobsForEvaluation(
-    QList<SchedulerJob *> &jobs, const QDateTime &now,
-    const QMap<QString, uint16_t> &capturedFramesCount, Scheduler *scheduler)
+    const QList<SchedulerJob *> &jobs, const QDateTime &now,
+    const QMap<QString, uint16_t> &capturedFramesCount, Scheduler *scheduler, bool reestimateJobTimes)
 {
     QList<SchedulerJob *> sortedJobs = jobs;
-
     // Remove some finished jobs from eval.
     foreach (SchedulerJob *job, sortedJobs)
     {
@@ -155,20 +168,23 @@ QList<SchedulerJob *> GreedyScheduler::prepareJobsForEvaluation(
         }
     }
 
-    // Change the starte to eval or ERROR/ABORTED for all jobs that will be evaluated.
+    // Estimate the job times
     foreach (SchedulerJob *job, sortedJobs)
     {
         if (job->getState() == SchedulerJob::JOB_INVALID || job->getState() == SchedulerJob::JOB_COMPLETE)
             continue;
-        job->setEstimatedTime(-1);
 
         // -1 = Job is not estimated yet
         // -2 = Job is estimated but time is unknown
         // > 0  Job is estimated and time is known
-        if (Scheduler::estimateJobTime(job, capturedFramesCount, scheduler) == false)
+        if (reestimateJobTimes)
         {
-            job->setState(SchedulerJob::JOB_INVALID);
-            continue;
+            job->setEstimatedTime(-1);
+            if (Scheduler::estimateJobTime(job, capturedFramesCount, scheduler) == false)
+            {
+                job->setState(SchedulerJob::JOB_INVALID);
+                continue;
+            }
         }
         if (job->getEstimatedTime() == 0)
         {
@@ -216,10 +232,24 @@ QDateTime firstPossibleStart(SchedulerJob *job, const QDateTime &now,
                              bool rescheduleErrors, int errorDelaySeconds)
 {
     QDateTime possibleStart = now;
-    if (job->getState() == SchedulerJob::JOB_ABORTED && rescheduleAbortsQueue)
-        possibleStart = job->getStateTime().addSecs(abortDelaySeconds);
-    if (job->getState() == SchedulerJob::JOB_ERROR && rescheduleErrors)
-        possibleStart = job->getStateTime().addSecs(errorDelaySeconds);
+    const QDateTime &abortTime = job->getLastAbortTime();
+    const QDateTime &errorTime = job->getLastErrorTime();
+
+    if (abortTime.isValid() && rescheduleAbortsQueue)
+    {
+        auto abortStartTime = abortTime.addSecs(abortDelaySeconds);
+        if (abortStartTime > now)
+            possibleStart = abortStartTime;
+    }
+
+
+    if (errorTime.isValid() && rescheduleErrors)
+    {
+        auto errorStartTime = errorTime.addSecs(errorDelaySeconds);
+        if (errorStartTime > now)
+            possibleStart = errorStartTime;
+    }
+
     if (!possibleStart.isValid() || possibleStart < now)
         possibleStart = now;
     return possibleStart;
@@ -238,7 +268,8 @@ QDateTime firstPossibleStart(SchedulerJob *job, const QDateTime &now,
 //   should be preempted for another job.
 SchedulerJob *GreedyScheduler::selectNextJob(const QList<SchedulerJob *> &jobs, const QDateTime &now,
         SchedulerJob *currentJob, bool fullSchedule, QDateTime *when,
-        QDateTime *nextInterruption, QString *interruptReason)
+        QDateTime *nextInterruption, QString *interruptReason,
+        const QMap<QString, uint16_t> *capturedFramesCount)
 {
     // Don't schedule a job that will be preempted in less than MIN_RUN_SECS.
     constexpr int MIN_RUN_SECS = 10 * 60;
@@ -266,6 +297,8 @@ SchedulerJob *GreedyScheduler::selectNextJob(const QList<SchedulerJob *> &jobs,
                                           job, now, rescheduleAbortsQueue, abortDelaySeconds, rescheduleErrors, errorDelaySeconds);
 
         // Find the first time this job can meet all its constraints.
+        // I found that passing in an "until" 4th argument actually hurt performance, as it reduces
+        // the effectiveness of the cache that getNextPossibleStartTime uses.
         const QDateTime startTime = job->getNextPossibleStartTime(startSearchingtAt, SCHEDULE_RESOLUTION_MINUTES,
                                     evaluatingCurrentJob);
         if (startTime.isValid())
@@ -302,6 +335,10 @@ SchedulerJob *GreedyScheduler::selectNextJob(const QList<SchedulerJob *> &jobs,
                     nextJob = job;
                 }
             }
+            // If scheduling, and we have a solution close enough to now, none of the lower priority
+            // jobs can possibly be scheduled.
+            if (!currentJob && nextStart.isValid() && now.secsTo(nextStart) < MIN_RUN_SECS)
+                break;
         }
         else if (evaluatingCurrentJob)
         {
@@ -380,12 +417,13 @@ SchedulerJob *GreedyScheduler::selectNextJob(const QList<SchedulerJob *> &jobs,
 
     constexpr int twoDays = 48 * 3600;
     if (fullSchedule && nextJob != nullptr)
-        simulate(jobs, now, now.addSecs(twoDays));
+        simulate(jobs, now, now.addSecs(twoDays), capturedFramesCount);
 
     return nextJob;
 }
 
-void GreedyScheduler::simulate(const QList<SchedulerJob *> &jobs, const QDateTime &time, const QDateTime &endTime)
+void GreedyScheduler::simulate(const QList<SchedulerJob *> &jobs, const QDateTime &time, const QDateTime &endTime,
+                               const QMap<QString, uint16_t> *capturedFramesCount)
 {
     schedule.clear();
 
@@ -418,8 +456,11 @@ void GreedyScheduler::simulate(const QList<SchedulerJob *> &jobs, const QDateTim
             numStartupCandidates++;
     }
 
-    QMap<QString, uint16_t> capturedFramesCount;
-    QList<SchedulerJob *>simJobs = prepareJobsForEvaluation(copiedJobs, time, capturedFramesCount, nullptr);
+    QMap<QString, uint16_t> capturedFramesCopy;
+    if (capturedFramesCount != nullptr)
+        capturedFramesCopy = *capturedFramesCount;
+    QList<SchedulerJob *>simJobs =
+        prepareJobsForEvaluation(copiedJobs, time, capturedFramesCopy, nullptr, false);
 
     QDateTime simTime = time;
     int iterations = 0;
@@ -440,9 +481,13 @@ void GreedyScheduler::simulate(const QList<SchedulerJob *> &jobs, const QDateTim
         if (selectedJob == nullptr)
             break;
 
+        // Are we past the end time?
+        if (endTime.isValid() && jobStartTime.secsTo(endTime) < 0) break;
+
         QString constraintReason;
         // Get the time that this next job would fail its constraints, and a human-readable explanation.
-        QDateTime jobConstraintTime = selectedJob->getNextEndTime(jobStartTime, SCHEDULE_RESOLUTION_MINUTES, &constraintReason);
+        QDateTime jobConstraintTime = selectedJob->getNextEndTime(jobStartTime, SCHEDULE_RESOLUTION_MINUTES, &constraintReason,
+                                      jobInterruptTime);
         QDateTime jobCompletionTime;
         if (selectedJob->getEstimatedTime() > 0)
         {
