@@ -12,6 +12,7 @@
 #include <QMap>
 #include "ksmoon.h"
 #include "kstarsdatetime.h"
+#include <QJsonObject>
 
 class ArtificialHorizon;
 class QTableWidgetItem;
@@ -26,6 +27,8 @@ class SchedulerJob
     public:
         SchedulerJob();
 
+        QJsonObject toJson() const;
+
         /** @brief States of a SchedulerJob. */
         typedef enum
         {
@@ -97,11 +100,11 @@ class SchedulerJob
         void setTargetCoords(const dms &ra, const dms &dec, double djd);
         /** @} */
 
-        double getRotation()
+        double getPositionAngle()
         {
-            return rotation;
+            return m_PositionAngle;
         }
-        void setRotation(double rotation);
+        void setPositionAngle(double value);
 
         /** @brief Capture sequence this job uses while running. */
         /** @{ */
@@ -294,6 +297,14 @@ class SchedulerJob
         {
             return stateTime;
         }
+        QDateTime getLastAbortTime() const
+        {
+            return lastAbortTime;
+        }
+        QDateTime getLastErrorTime() const
+        {
+            return lastErrorTime;
+        }
         void setState(const JOBStatus &value);
         /** @} */
 
@@ -592,9 +603,11 @@ class SchedulerJob
              * @return The date and time the target meets or misses constraints.
              */
         QDateTime calculateNextTime(QDateTime const &when, bool checkIfConstraintsAreMet = true, int increment = 1,
-                                    QString *reason = nullptr, bool runningJob = false) const;
-        QDateTime getNextPossibleStartTime(const QDateTime &when, int increment = 1, bool runningJob = false) const;
-        QDateTime getNextEndTime(const QDateTime &start, int increment = 1, QString *reason = nullptr) const;
+                                    QString *reason = nullptr, bool runningJob = false, const QDateTime &until = QDateTime()) const;
+        QDateTime getNextPossibleStartTime(const QDateTime &when, int increment = 1, bool runningJob = false,
+                                           const QDateTime &until = QDateTime()) const;
+        QDateTime getNextEndTime(const QDateTime &start, int increment = 1, QString *reason = nullptr,
+                                 const QDateTime &until = QDateTime()) const;
 
         /**
              * @brief calculateCulmination find culmination time adjust for the job offset
@@ -634,7 +647,7 @@ class SchedulerJob
              * @return true if the next dawn/dusk event after this observation is the astronomical dawn, else false.
              * @note This function relies on the guarantee that dawn and dusk are calculated to be the first events after this observation.
              */
-        bool runsDuringAstronomicalNightTime(const QDateTime &time = QDateTime()) const;
+        bool runsDuringAstronomicalNightTime(const QDateTime &time = QDateTime(), QDateTime *nextPossibleSuccess = nullptr) const;
 
         /**
              * @brief findAltitude Find altitude given a specific time
@@ -669,8 +682,19 @@ class SchedulerJob
         static QString completionConditionString(SchedulerJob::CompletionCondition condition);
         QString jobCompletionConditionString(SchedulerJob::CompletionCondition condition) const;
 
+        static void enableGraphicsUpdates(bool update)
+        {
+            m_UpdateGraphics = update;
+        }
+
+        // Clear the cache that keeps results for getNextPossibleStartTime().
+        void clearCache()
+        {
+            startTimeCache.clear();
+        }
     private:
-        bool runsDuringAstronomicalNightTimeInternal(const QDateTime &time, QDateTime *minDawnDusk) const;
+        bool runsDuringAstronomicalNightTimeInternal(const QDateTime &time, QDateTime *minDawnDusk,
+                QDateTime *nextPossibleSuccess = nullptr) const;
 
         // Private constructor for unit testing.
         SchedulerJob(KSMoon *moonPtr);
@@ -711,13 +735,15 @@ class SchedulerJob
 
         QString name;
         SkyPoint targetCoords;
-        double rotation { -1 };
+        double m_PositionAngle { -1 };
         JOBStatus state { JOB_IDLE };
         JOBStage stage { STAGE_IDLE };
 
         // The time that the job stage was set.
         // Used by the Greedy Algorithm to decide when to run JOB_ABORTED jobs again.
         QDateTime stateTime;
+        QDateTime lastAbortTime;
+        QDateTime lastErrorTime;
 
         StartupCondition fileStartupCondition { START_ASAP };
         StartupCondition startupCondition { START_ASAP };
@@ -792,6 +818,39 @@ class SchedulerJob
         /// Pointer to Moon object
         KSMoon *moon { nullptr };
 
+        // There are times when we pause graphics updates for all jobs.
+        static bool m_UpdateGraphics;
+
+        // This class is used to cache the results computed in getNextPossibleStartTime()
+        // which is called repeatedly by the Greedy scheduler.
+        // The cache would need to be cleared if something changes that would affect the
+        // start time of jobs (geography, altitide constraints) so it is reset at the start
+        // of all schedule calculations--which does not impact its effectiveness.
+        class StartTimeCache
+        {
+                // Keep track of calls to getNextPossibleStartTime, storing the when, until and result.
+                struct StartTimeComputation
+                {
+                    QDateTime from;
+                    QDateTime until;
+                    QDateTime result;
+                };
+            public:
+                StartTimeCache() {}
+                // Check if the computation has been done, and if so, return the previous result.
+                bool check(const QDateTime &from, const QDateTime &until,
+                           QDateTime *result, QDateTime *newFrom) const;
+                // Add a result to the cache.
+                void add(const QDateTime &from, const QDateTime &until, const QDateTime &result) const;
+                // Clear the cache.
+                void clear() const;
+            private:
+                // Made this mutable and all methods const so that the cache could be
+                // used in SchedulerJob const methods.
+                mutable QList<StartTimeComputation> startComputations;
+        };
+        StartTimeCache startTimeCache;
+
         // These are used in testing, instead of KStars::Instance() resources
         static KStarsDateTime *storedLocalTime;
         static GeoLocation *storedGeo;
