@@ -78,7 +78,7 @@ class FITSData : public QObject
     public:
         explicit FITSData(FITSMode fitsMode = FITS_NORMAL);
         explicit FITSData(const QSharedPointer<FITSData> &other);
-        ~FITSData();
+        ~FITSData() override;
 
         /** Structure to hold FITS Header records */
         typedef struct
@@ -104,21 +104,18 @@ class FITSData : public QObject
         /**
          * @brief loadFITS Loading FITS file asynchronously.
          * @param inFilename Path to FITS file (or compressed fits.gz)
-         * @param silent If set, error messages are ignored. If set to false, the error message will get displayed in a popup.
          * @return A QFuture that can be watched until the async operation is complete.
          */
-        QFuture<bool> loadFromFile(const QString &inFilename, bool silent = true);
+        QFuture<bool> loadFromFile(const QString &inFilename);
 
         /**
          * @brief loadFITSFromMemory Loading FITS from memory buffer.
          * @param buffer The memory buffer containing the fits data.
          * @param extension file extension (e.g. "jpg", "fits", "cr2"...etc)
          * @param inFilename Set filename metadata, does not load from file.
-         * @param silent If set, error messages are ignored. If set to false, the error message will get displayed in a popup.
          * @return bool indicating success or failure.
          */
-        bool loadFromBuffer(const QByteArray &buffer, const QString &extension, const QString &inFilename = QString(),
-                            bool silent = true);
+        bool loadFromBuffer(const QByteArray &buffer, const QString &extension, const QString &inFilename = QString());
 
         /**
          * @brief parseSolution Parse the WCS solution information from the header into the given struct.
@@ -142,45 +139,46 @@ class FITSData : public QObject
         ////////////////////////////////////////////////////////////////////////////////////////
         ////////////////////////////////////////////////////////////////////////////////////////
         // Calculate stats
-        void calculateStats(bool refresh = false);
+        void calculateStats(bool refresh = false, bool roi = false);
         void saveStatistics(FITSImage::Statistic &other);
         void restoreStatistics(FITSImage::Statistic &other);
         FITSImage::Statistic const &getStatistics() const
         {
             return m_Statistics;
-        };
+        }
 
-        uint16_t width() const
+        uint16_t width(bool roi = false) const
         {
-            return m_Statistics.width;
+            return roi ?  m_ROIStatistics.width : m_Statistics.width;
         }
-        uint16_t height() const
+        uint16_t height(bool roi = false) const
         {
-            return m_Statistics.height;
+            return roi ?  m_ROIStatistics.height : m_Statistics.height;
         }
-        int64_t size() const
+        int64_t size(bool roi = false) const
         {
-            return m_Statistics.size;
+            return roi ?  m_ROIStatistics.size : m_Statistics.size;
         }
         int channels() const
         {
             return m_Statistics.channels;
         }
-        uint32_t samplesPerChannel() const
+        uint32_t samplesPerChannel(bool roi = false) const
         {
-            return m_Statistics.samples_per_channel;
+            return roi ?  m_ROIStatistics.samples_per_channel : m_Statistics.samples_per_channel;
         }
         uint32_t dataType() const
         {
             return m_Statistics.dataType;
         }
-        double getMin(uint8_t channel = 0) const
+        double getMin(uint8_t channel = 0, bool roi = false) const
         {
-            return m_Statistics.min[channel];
+            return roi ?  m_ROIStatistics.min[channel] : m_Statistics.min[channel];
         }
-        double getMax(uint8_t channel = 0) const
+        double getMax(uint8_t channel = 0, bool roi = false) const
         {
-            return m_Statistics.max[channel];
+            return roi ?  m_ROIStatistics.max[channel] : m_Statistics.max[channel];
+
         }
         void setMinMax(double newMin, double newMax, uint8_t channel = 0);
         void getMinMax(double *min, double *max, uint8_t channel = 0) const
@@ -192,32 +190,32 @@ class FITSData : public QObject
         {
             m_Statistics.stddev[channel] = value;
         }
-        double getStdDev(uint8_t channel = 0) const
+        double getStdDev(uint8_t channel = 0, bool roi = false ) const
         {
-            return m_Statistics.stddev[channel];
+            return roi ? m_ROIStatistics.stddev[channel] :  m_Statistics.stddev[channel];
         }
-        double getAverageStdDev() const;
+        double getAverageStdDev(bool roi = false) const;
         void setMean(double value, uint8_t channel = 0)
         {
             m_Statistics.mean[channel] = value;
         }
-        double getMean(uint8_t channel = 0) const
+        double getMean(uint8_t channel = 0, bool roi = false) const
         {
-            return m_Statistics.mean[channel];
+            return roi ? m_ROIStatistics.mean[channel] :  m_Statistics.mean[channel];
         }
         // for single channel, just return the mean for channel zero
         // for color, return the average
-        double getAverageMean() const;
+        double getAverageMean(bool roi = false) const;
         void setMedian(double val, uint8_t channel = 0)
         {
             m_Statistics.median[channel] = val;
         }
         // for single channel, just return the median for channel zero
         // for color, return the average
-        double getAverageMedian() const;
-        double getMedian(uint8_t channel = 0) const
+        double getAverageMedian(bool roi = false) const;
+        double getMedian(uint8_t channel = 0, bool roi = false) const
         {
-            return m_Statistics.median[channel];
+            return roi ? m_ROIStatistics.median[channel] :  m_Statistics.median[channel];
         }
 
         int getBytesPerPixel() const
@@ -238,20 +236,16 @@ class FITSData : public QObject
             {
                 case TBYTE:
                     return 8;
-                    break;
                 case TSHORT:
                 case TUSHORT:
                     return 16;
-                    break;
                 case TLONG:
                 case TULONG:
                 case TFLOAT:
                     return 32;
-                    break;
                 case TLONGLONG:
                 case TDOUBLE:
                     return 64;
-                    break;
                 default:
                     return 8;
             }
@@ -324,7 +318,7 @@ class FITSData : public QObject
         // Use SEP (Sextractor Library) to find stars
         template <typename T>
         void getFloatBuffer(float *buffer, int x, int y, int w, int h) const;
-        //int findSEPStars(QList<Edge*> &, const QRect &boundary = QRect()) const;
+        //int findSEPStars(QList<Edge*> &, const int8_t &boundary = int8_t()) const;
 
         // Apply ring filter to searched stars
         int filterStars(const float innerRadius, const float outerRadius);
@@ -358,6 +352,16 @@ class FITSData : public QObject
             m_DateTime = t;
         }
 
+        const QPoint getRoiCenter() const
+        {
+            return roiCenter;
+        }
+
+        void setRoiCenter(QPoint c)
+        {
+            roiCenter = c;
+        }
+
         ////////////////////////////////////////////////////////////////////////////////////////
         ////////////////////////////////////////////////////////////////////////////////////////
         /// World Coordinate System (WCS) Functions.
@@ -404,15 +408,14 @@ class FITSData : public QObject
         bool pixelToWCS(const QPointF &wcsPixelPoint, SkyPoint &wcsCoord);
 
         /**
-             * @brief injectWCS Add WCS keywords to file
+             * @brief injectWCS Add WCS keywords
              * @param orientation Solver orientation, degrees E of N.
              * @param ra J2000 Right Ascension
              * @param dec J2000 Declination
              * @param pixscale Pixel scale in arcsecs per pixel
              * @param eastToTheRight if true, then when the image is rotated so that north is up, then east would be to the right on the image.
-             * @return  True if file is successfully updated with WCS info.
              */
-        bool injectWCS(double orientation, double ra, double dec, double pixscale, bool eastToTheRight);
+        void injectWCS(double orientation, double ra, double dec, double pixscale, bool eastToTheRight);
 
         ////////////////////////////////////////////////////////////////////////////////////////
         ////////////////////////////////////////////////////////////////////////////////////////
@@ -563,27 +566,28 @@ class FITSData : public QObject
          * @brief dataChanged Send signal when undelying raw data buffer data changed.
          */
         void dataChanged();
+    public slots:
+        void makeRoiBuffer(QRect roi);
 
     private:
         void loadCommon(const QString &inFilename);
         /**
          * @brief privateLoad Load an image (FITS, RAW, or images supported by Qt like jpeg, png).
          * @param Buffer pointer to image data. If buffer is emtpy, read from disk (m_Filename).
-         * @param silent If true, suppress any messages.
          * @return true if successfully loaded, false otherwise.
          */
-        bool privateLoad(const QByteArray &buffer, const QString &extension, bool silent);
+        bool privateLoad(const QByteArray &buffer, const QString &extension);
 
         // Load Qt-supported images.
-        bool loadCanonicalImage(const QByteArray &buffer, const QString &extension, bool silent);
+        bool loadCanonicalImage(const QByteArray &buffer, const QString &extension);
         // Load FITS images.
-        bool loadFITSImage(const QByteArray &buffer, const QString &extension, bool silent);
+        bool loadFITSImage(const QByteArray &buffer, const QString &extension);
         // Load RAW images.
-        bool loadRAWImage(const QByteArray &buffer, const QString &extension, bool silent);
+        bool loadRAWImage(const QByteArray &buffer, const QString &extension);
 
         void rotWCSFITS(int angle, int mirror);
-        void calculateMinMax(bool refresh = false);
-        void calculateMedian(bool refresh = false);
+        void calculateMinMax(bool refresh = false, bool roi = false);
+        void calculateMedian(bool refresh = false, bool roi = false);
         bool checkDebayer();
         void readWCSKeys();
 
@@ -607,12 +611,12 @@ class FITSData : public QObject
         void applyFilter(FITSScale type, uint8_t *targetImage, QVector<double> * min = nullptr, QVector<double> * max = nullptr);
 
         template <typename T>
-        void calculateMinMax();
+        void calculateMinMax(bool roi = false);
         template <typename T>
-        void calculateMedian();
+        void calculateMedian(bool roi = false);
 
         template <typename T>
-        QPair<T, T> getParitionMinMax(uint32_t start, uint32_t stride);
+        QPair<T, T> getParitionMinMax(uint32_t start, uint32_t stride, bool roi);
 
         /* Calculate the Gaussian blur matrix and apply it to the image using the convolution filter */
         QVector<double> createGaussianKernel(int size, double sigma);
@@ -623,9 +627,9 @@ class FITSData : public QObject
 
         /* Calculate running average & standard deviation using Welford’s method for computing variance */
         template <typename T>
-        void runningAverageStdDev();
+        void runningAverageStdDev( bool roi = false );
         template <typename T>
-        QPair<double, double> getSquaredSumAndMean(uint32_t start, uint32_t stride);
+        QPair<double, double> getSquaredSumAndMean(uint32_t start, uint32_t stride, bool roi = false);
 
         template <typename T>
         void convertToQImage(double dataMin, double dataMax, double scale, double zero, QImage &image);
@@ -643,6 +647,10 @@ class FITSData : public QObject
         uint8_t *m_ImageBuffer { nullptr };
         /// Above buffer size in bytes
         uint32_t m_ImageBufferSize { 0 };
+        /// Image Buffer if Selection is to be done
+        uint8_t *m_ImageRoiBuffer { nullptr };
+        /// Above buffer size in bytes
+        uint32_t m_ImageRoiBufferSize { 0 };
         /// Is this a temporary file or one loaded from disk?
         bool m_isTemporary { false };
         /// is this file compress (.fits.fz)?
@@ -697,6 +705,7 @@ class FITSData : public QObject
         /// 16bit can be either SHORT_IMG or USHORT_IMG, so m_FITSBITPIX specifies which is
         int m_FITSBITPIX {USHORT_IMG};
         FITSImage::Statistic m_Statistics;
+        FITSImage::Statistic m_ROIStatistics;
 
         // A list of header records
         QList<Record> m_HeaderRecords;
@@ -735,4 +744,5 @@ class FITSData : public QObject
         double cacheHFR { -1 };
         HFRType cacheHFRType { HFR_AVERAGE };
         double cacheEccentricity { -1 };
+        QPoint roiCenter;
 };
