@@ -34,11 +34,25 @@
 #define ZOOM_LOW_INCR  10
 #define ZOOM_HIGH_INCR 50
 
-FITSLabel::FITSLabel(FITSView *view, QWidget *parent) : QLabel(parent)
+FITSLabel::FITSLabel(FITSView *View, QWidget *parent) : QLabel(parent)
 {
-    this->view = view;
+    this->view = View;
+    prevscale = 0.0;
+    //Rubber Band options
+    roiRB = new QRubberBand( QRubberBand::Rectangle, this);
+    roiRB->setAttribute(Qt::WA_TransparentForMouseEvents, 1);
+    roiRB->setGeometry(QRect(QPoint(1, 1), QPoint(100, 100)));
+
+    QPalette pal;
+    QColor red70 = Qt::red;
+    red70.setAlphaF(0.7);
+
+    pal.setBrush(QPalette::Highlight, QBrush(red70));
+    roiRB->setPalette(pal);
+    QToolTip::showText(QPoint(1, 1), "Move Once to show selection stats", this);
 }
 
+
 void FITSLabel::setSize(double w, double h)
 {
     m_Width  = w;
@@ -57,17 +71,38 @@ If the mouse button is released, it resets mouseButtonDown variable and the mous
  */
 void FITSLabel::mouseReleaseEvent(QMouseEvent *e)
 {
-    Q_UNUSED(e)
+    float scale = (view->getCurrentZoom() / ZOOM_DEFAULT);
+
+    double x = round(e->x() / scale);
+    double y = round(e->y() / scale);
+
+    m_p2.setX(x);//record second point for selection Rectangle
+    m_p2.setY(y);
+
     if (view->getCursorMode() == FITSView::dragCursor)
     {
         mouseButtonDown = false;
         view->updateMouseCursor();
+        if( isRoiSelected && view->isSelectionRectShown())
+        {
+            QRect roiRaw = roiRB->geometry();
+            emit rectangleSelected(roiRaw.topLeft() / prevscale, roiRaw.bottomRight() / prevscale, true);
+            updateROIToolTip(e->globalPos());
+        }
+        if( e->modifiers () == Qt::ShiftModifier && view->isSelectionRectShown())
+        {
+            QRect roiRaw = roiRB->geometry();
+            emit rectangleSelected(roiRaw.topLeft() / prevscale, roiRaw.bottomRight() / prevscale, true);
+            updateROIToolTip(e->globalPos());
+        }
+        isRoiSelected = false;
     }
+
 }
 
 void FITSLabel::leaveEvent(QEvent *e)
 {
-    Q_UNUSED(e);
+    Q_UNUSED(e)
     view->updateMagnifyingGlass(-1, -1);
 }
 
@@ -80,9 +115,17 @@ Then it stores the current point so next time it can do it again.
  */
 void FITSLabel::mouseMoveEvent(QMouseEvent *e)
 {
+    const QSharedPointer<FITSData> &imageData = view->imageData();
+    if (imageData.isNull())
+        return;
+
     float scale = (view->getCurrentZoom() / ZOOM_DEFAULT);
 
-    if (view->getCursorMode() == FITSView::dragCursor && mouseButtonDown)
+    double x = round(e->x() / scale);
+    double y = round(e->y() / scale);
+
+    //Panning
+    if (e->modifiers() != Qt::ShiftModifier  && view->getCursorMode() == FITSView::dragCursor && mouseButtonDown  )
     {
         QPoint newPoint = e->globalPos();
         int dx          = newPoint.x() - lastMousePoint.x();
@@ -92,11 +135,41 @@ void FITSLabel::mouseMoveEvent(QMouseEvent *e)
 
         lastMousePoint = newPoint;
     }
+    if( e->buttons() & Qt::LeftButton && view->getCursorMode() == FITSView::dragCursor )
+    {
+        //Translation of ROI
+        if(isRoiSelected && !mouseButtonDown)
+        {
 
-    double x, y;
-    const QSharedPointer<FITSData> &view_data = view->imageData();
+            int xdiff = x - prevPoint.x();
+            int ydiff = y - prevPoint.y();
+            roiRB->setGeometry(roiRB->geometry().translated(round(xdiff * scale), round(ydiff * scale)));
+            prevPoint = QPoint(x, y);
 
-    uint8_t const *buffer = view_data->getImageBuffer();
+            QRect roiRaw = roiRB->geometry();
+            // Opting to update stats on the go is extremely laggy for large images, only update if small image
+            if(!view->isLargeImage())
+            {
+                emit rectangleSelected(roiRaw.topLeft() / prevscale, roiRaw.bottomRight() / prevscale, true);
+                updateROIToolTip(e->globalPos());
+            }
+        }
+        //Stretching of ROI
+        if(e->modifiers() == Qt::ShiftModifier && !isRoiSelected && view->isSelectionRectShown())
+        {
+            roiRB->setGeometry(QRect(m_p1 * scale, QPoint(x, y)*scale).normalized());
+
+            QRect roiRaw = roiRB->geometry();
+            // Opting to update stats on the go is extremely laggy for large images, only update if small image
+            if(!view->isLargeImage())
+            {
+                emit rectangleSelected(roiRaw.topLeft() / prevscale, roiRaw.bottomRight() / prevscale, true);
+                updateROIToolTip(e->globalPos());
+            }
+        }
+    }
+
+    uint8_t const *buffer = imageData->getImageBuffer();
 
     if (buffer == nullptr)
         return;
@@ -121,7 +194,7 @@ void FITSLabel::mouseMoveEvent(QMouseEvent *e)
     int index = y * m_Width + x;
     QString stringValue;
 
-    switch (view_data->getStatistics().dataType)
+    switch (imageData->getStatistics().dataType)
     {
         case TBYTE:
             stringValue = QLocale().toString(buffer[index]);
@@ -158,15 +231,26 @@ void FITSLabel::mouseMoveEvent(QMouseEvent *e)
 
         default:
             break;
+
+    }
+
+    if(view->isSelectionRectShown())
+    {
+        if (roiRB->geometry().contains(e->pos()))
+            updateROIToolTip(e->globalPos());
+        else
+            QToolTip::hideText();
     }
 
     emit newStatus(stringValue, FITS_VALUE);
 
-    if (view_data->hasWCS() && view->getCursorMode() != FITSView::selectCursor)
+    if (imageData->hasWCS() &&
+            !view->isSelectionRectShown() &&
+            view->getCursorMode() != FITSView::selectCursor)
     {
         QPointF wcsPixelPoint(x, y);
         SkyPoint wcsCoord;
-        if(view_data->pixelToWCS(wcsPixelPoint, wcsCoord))
+        if(imageData->pixelToWCS(wcsPixelPoint, wcsCoord))
         {
             m_RA = wcsCoord.ra0();
             m_DE = wcsCoord.dec0();
@@ -174,24 +258,26 @@ void FITSLabel::mouseMoveEvent(QMouseEvent *e)
         }
 
         bool objFound = false;
-        for (auto &listObject : view_data->getSkyObjects())
+        for (auto &listObject : imageData->getSkyObjects())
         {
             if ((std::abs(listObject->x() - x) < 5 / scale) && (std::abs(listObject->y() - y) < 5 / scale))
             {
                 QToolTip::showText(e->globalPos(),
-                                   listObject->skyObject()->name() + '\n' + listObject->skyObject()->longname(), this);
+                                   QToolTip::text() + '\n' + listObject->skyObject()->name() + '\n' + listObject->skyObject()->longname(), this);
                 objFound = true;
                 break;
             }
         }
-        if (!objFound)
+        if (!objFound && !view->isSelectionRectShown())
             QToolTip::hideText();
     }
 
     double HFR = view->imageData()->getHFR(x, y);
 
+
     if (HFR > 0)
-        QToolTip::showText(e->globalPos(), i18nc("Half Flux Radius", "HFR: %1", QString::number(HFR, 'g', 3)), this);
+        QToolTip::showText(e->globalPos(), QToolTip::text() + '\n' + i18nc("Half Flux Radius", "HFR: %1", QString::number(HFR, 'g',
+                           3)), this);
 
     //setCursor(Qt::CrossCursor);
 
@@ -213,10 +299,20 @@ void FITSLabel::mousePressEvent(QMouseEvent *e)
     double x = round(e->x() / scale);
     double y = round(e->y() / scale);
 
+    m_p1.setX(x);//record first point for selection Rectangle
+    m_p1.setY(y);
+    prevPoint = QPoint(x, y);
+    prevscale = scale;
     x = KSUtils::clamp(x, 1.0, m_Width);
     y = KSUtils::clamp(y, 1.0, m_Height);
 
-    if (view->getCursorMode() == FITSView::dragCursor)
+    if(e->buttons() & Qt::LeftButton && view->getCursorMode() == FITSView::dragCursor)
+    {
+        if(roiRB->geometry().contains(x * scale, y * scale))
+            isRoiSelected = true;
+    }
+
+    if (view->getCursorMode() == FITSView::dragCursor && !isRoiSelected)
     {
         mouseButtonDown = true;
         lastMousePoint  = e->globalPos();
@@ -360,3 +456,70 @@ void FITSLabel::centerTelescope(double raJ2000, double decJ2000)
 
 #endif
 }
+
+void FITSLabel::showRubberBand(bool on)
+{
+    if(on)
+    {
+        roiRB->show();
+    }
+    else
+    {
+        roiRB->hide();
+    }
+}
+
+/// Scales the rubberband on zoom
+void FITSLabel::zoomRubberBand(double scale)
+{
+    QRect r = roiRB->geometry() ;
+
+    if(prevscale == 0.0 )
+        prevscale = scale;
+
+    double ap = r.width() / r.height();
+    double ow = r.width() * scale / prevscale;
+    double oh = r.height() * scale / prevscale;
+
+    int rx, ry;
+    rx = round(r.topLeft().x() * scale / prevscale);
+    ry = round(r.topLeft().y() * scale / prevscale);
+    r.setTopLeft(QPoint(rx, ry));
+
+    rx = round(r.bottomRight().x() * scale / prevscale);
+    ry = round(r.bottomRight().y() * scale / prevscale);
+    r.setBottomRight(QPoint(rx, ry));
+
+    if (ap != r.width() / r.height())
+    {
+        r.setSize(QSize(ow, oh));
+    }
+
+    roiRB->setGeometry(r);
+    prevscale = scale;
+}
+/// Intended to take raw rect as input from FITSView context
+void FITSLabel::setRubberBand(QRect rect)
+{
+    float scale = (view->getCurrentZoom() / ZOOM_DEFAULT);
+
+    int rx, ry;
+    rx = round(rect.topLeft().x() * scale );
+    ry = round(rect.topLeft().y() * scale );
+    rect.setTopLeft(QPoint(rx, ry));
+
+    rx = round(rect.bottomRight().x() * scale );
+    ry = round(rect.bottomRight().y() * scale );
+    rect.setBottomRight(QPoint(rx, ry));
+
+    roiRB->setGeometry(rect);
+    prevscale = scale;
+}
+
+void FITSLabel::updateROIToolTip(const QPoint p)
+{
+    auto result = QString("σ %1").arg(QString::number(view->imageData()->getAverageStdDev(true), 'f', 2));
+    result += "\nx̄ " + QString::number(view->imageData()->getAverageMean(true), 'f', 2);
+    result += "\nM " + QString::number(view->imageData()->getAverageMedian(true), 'f', 2);
+    QToolTip::showText(p, result, this);
+}
