@@ -202,6 +202,12 @@ FITSView::FITSView(QWidget * parent, FITSMode fitsMode, FITSScale filterType) :
     connect(m_ImageFrame, &FITSLabel::newStatus, this, &FITSView::newStatus);
     connect(m_ImageFrame, &FITSLabel::pointSelected, this, &FITSView::processPointSelection);
     connect(m_ImageFrame, &FITSLabel::markerSelected, this, &FITSView::processMarkerSelection);
+    connect(m_ImageFrame, &FITSLabel::rectangleSelected, this, &FITSView::processRectangle);
+    connect(this, &FITSView::setRubberBand, m_ImageFrame, &FITSLabel::setRubberBand);
+    connect(this, &FITSView::showRubberBand, m_ImageFrame, &FITSLabel::showRubberBand);
+    connect(this, &FITSView::zoomRubberBand, m_ImageFrame, &FITSLabel::zoomRubberBand);
+
+
 
     connect(&wcsWatcher, &QFutureWatcher<bool>::finished, this, &FITSView::syncWCSState);
 
@@ -305,7 +311,7 @@ void FITSView::resizeEvent(QResizeEvent * event)
 }
 
 
-void FITSView::loadFile(const QString &inFilename, bool silent)
+void FITSView::loadFile(const QString &inFilename)
 {
     if (floatingToolBar != nullptr)
     {
@@ -339,7 +345,7 @@ void FITSView::loadFile(const QString &inFilename, bool silent)
     if (setBayerParams)
         m_ImageData->setBayerParams(&param);
 
-    fitsWatcher.setFuture(m_ImageData->loadFromFile(inFilename, silent));
+    fitsWatcher.setFuture(m_ImageData->loadFromFile(inFilename));
 }
 
 void FITSView::clearData()
@@ -375,6 +381,7 @@ bool FITSView::loadData(const QSharedPointer<FITSData> &data)
     // Takes control of the objects passed in.
     m_ImageData = data;
 
+
     return processData();
 }
 
@@ -384,12 +391,19 @@ bool FITSView::processData()
     if (!m_ImageData)
         return false;
 
-    connect(m_ImageData.data(), &FITSData::dataChanged, [this]()
+    connect(m_ImageData.data(), &FITSData::dataChanged, this, [this]()
     {
         rescale(ZOOM_KEEP_LEVEL);
         updateFrame();
     });
 
+    connect(this, &FITSView::rectangleUpdated, this, [this](const QRect roi)
+    {
+        if(m_ImageData)
+        {
+            m_ImageData->makeRoiBuffer(roi);
+        }
+    });
     currentWidth = m_ImageData->width();
     currentHeight = m_ImageData->height();
 
@@ -400,9 +414,9 @@ bool FITSView::processData()
     {
         m_ImageFrame = new FITSLabel(this);
         m_ImageFrame->setMouseTracking(true);
-        connect(m_ImageFrame, SIGNAL(newStatus(QString, FITSBar)), this, SIGNAL(newStatus(QString, FITSBar)));
-        connect(m_ImageFrame, SIGNAL(pointSelected(int, int)), this, SLOT(processPointSelection(int, int)));
-        connect(m_ImageFrame, SIGNAL(markerSelected(int, int)), this, SLOT(processMarkerSelection(int, int)));
+        connect(m_ImageFrame, &FITSLabel::newStatus, this, &FITSView::newStatus);
+        connect(m_ImageFrame, &FITSLabel::pointSelected, this, &FITSView::processPointSelection);
+        connect(m_ImageFrame, &FITSLabel::markerSelected, this, &FITSView::processMarkerSelection);
     }
     m_ImageFrame->setSize(image_width, image_height);
 
@@ -485,11 +499,12 @@ bool FITSView::processData()
 
 void FITSView::loadInFrame()
 {
+    m_LastError = m_ImageData->getLastError();
+
     // Check if the loading was OK
     if (fitsWatcher.result() == false)
     {
-        m_LastError = m_ImageData->getLastError();
-        emit failed();
+        emit failed(m_LastError);
         return;
     }
 
@@ -499,7 +514,7 @@ void FITSView::loadInFrame()
     if (processData())
         emit loaded();
     else
-        emit failed();
+        emit failed(m_LastError);
 }
 
 bool FITSView::saveImage(const QString &newFilename)
@@ -653,6 +668,7 @@ void FITSView::ZoomIn()
     updateFrame(true);
 
     emit newStatus(QString("%1%").arg(currentZoom), FITS_ZOOM);
+    emit zoomRubberBand(getCurrentZoom() / ZOOM_DEFAULT);
 }
 
 void FITSView::ZoomOut()
@@ -681,6 +697,7 @@ void FITSView::ZoomOut()
     updateFrame(true);
 
     emit newStatus(QString("%1%").arg(currentZoom), FITS_ZOOM);
+    emit zoomRubberBand(getCurrentZoom() / ZOOM_DEFAULT);
 }
 
 void FITSView::ZoomToFit()
@@ -693,6 +710,7 @@ void FITSView::ZoomToFit()
         rescale(ZOOM_FIT_WINDOW);
         updateFrame(true);
     }
+    emit zoomRubberBand(getCurrentZoom() / ZOOM_DEFAULT);
 }
 
 void FITSView::setStarFilterRange(float const innerRadius, float const outerRadius)
@@ -801,6 +819,7 @@ void FITSView::updateFrameSmallImage()
     m_ImageFrame->resize(currentWidth, currentHeight);
 }
 
+
 void FITSView::drawStarFilter(QPainter *painter, double scale)
 {
     if (!starFilter.used())
@@ -825,8 +844,9 @@ namespace
 {
 
 template <typename T>
-void drawClippingOneChannel(T *inputBuffer, QPainter *painter, int width, int height, double clipVal, double scale)
+int drawClippingOneChannel(T *inputBuffer, QPainter *painter, int width, int height, double clipVal, double scale)
 {
+    int numClipped = 0;
     painter->save();
     painter->setPen(QPen(Qt::red, scale, Qt::SolidLine));
     const T clipping = clipVal;
@@ -836,19 +856,25 @@ void drawClippingOneChannel(T *inputBuffer, QPainter *painter, int width, int he
         for (int x = 0; x < width; x++)
         {
             if (inputLine[x] > clipping)
+            {
                 painter->drawPoint(x, y);
+                numClipped++;
+            }
         }
     }
+    fprintf(stderr, "%d of %d clipped (%.2f%%)\n", numClipped, width * height, numClipped * 100.0 / (width * height));
     painter->restore();
+    return numClipped;
 }
 
 template <typename T>
-void drawClippingThreeChannels(T *inputBuffer, QPainter *painter, int width, int height, double clipVal, double scale)
+int drawClippingThreeChannels(T *inputBuffer, QPainter *painter, int width, int height, double clipVal, double scale)
 {
     painter->save();
     painter->setPen(QPen(Qt::red, scale, Qt::SolidLine));
     const int size = width * height;
     const T clipping = clipVal;
+    int numClipped = 0;
     for (int y = 0; y < height; y++)
     {
         // R, G, B input images are stored one after another.
@@ -862,19 +888,25 @@ void drawClippingThreeChannels(T *inputBuffer, QPainter *painter, int width, int
             const T inputG = inputLineG[x];
             const T inputB = inputLineB[x];
             if (inputR > clipping || inputG > clipping || inputB > clipping)
+            {
                 painter->drawPoint(x, y);
+                numClipped++;
+            }
         }
     }
+    fprintf(stderr, "%d of %d clipped (%.2f%%)\n", numClipped, width * height, numClipped * 100.0 / (width * height));
     painter->restore();
+    return numClipped;
 }
 
 template <typename T>
-void drawClip(T *input_buffer, int num_channels, QPainter *painter, int width, int height, double clipVal, double scale)
+int drawClip(T *input_buffer, int num_channels, QPainter *painter, int width, int height, double clipVal, double scale)
 {
     if (num_channels == 1)
-        drawClippingOneChannel(input_buffer, painter, width, height, clipVal, scale);
+        return drawClippingOneChannel(input_buffer, painter, width, height, clipVal, scale);
     else if (num_channels == 3)
-        drawClippingThreeChannels(input_buffer, painter, width, height, clipVal, scale);
+        return drawClippingThreeChannels(input_buffer, painter, width, height, clipVal, scale);
+    else return 0;
 }
 
 }  // namespace
@@ -891,36 +923,41 @@ void FITSView::drawClipping(QPainter *painter)
     switch (m_ImageData->dataType())
     {
         case TBYTE:
-            drawClip(reinterpret_cast<uint8_t const*>(input), m_ImageData->channels(), painter, width, height, BYTE_CLIP,
-                     scaleSize(1));
+            m_NumClipped = drawClip(reinterpret_cast<uint8_t const*>(input), m_ImageData->channels(), painter, width, height, BYTE_CLIP,
+                                    scaleSize(1));
             break;
         case TSHORT:
-            drawClip(reinterpret_cast<short const*>(input), m_ImageData->channels(), painter, width, height, SHORT_CLIP,
-                     scaleSize(1));
+            m_NumClipped = drawClip(reinterpret_cast<short const*>(input), m_ImageData->channels(), painter, width, height, SHORT_CLIP,
+                                    scaleSize(1));
             break;
         case TUSHORT:
-            drawClip(reinterpret_cast<unsigned short const*>(input), m_ImageData->channels(), painter, width, height, USHORT_CLIP,
-                     scaleSize(1));
+            m_NumClipped = drawClip(reinterpret_cast<unsigned short const*>(input), m_ImageData->channels(), painter, width, height,
+                                    USHORT_CLIP,
+                                    scaleSize(1));
             break;
         case TLONG:
-            drawClip(reinterpret_cast<long const*>(input), m_ImageData->channels(), painter, width, height, USHORT_CLIP,
-                     scaleSize(1));
+            m_NumClipped = drawClip(reinterpret_cast<long const*>(input), m_ImageData->channels(), painter, width, height, USHORT_CLIP,
+                                    scaleSize(1));
             break;
         case TFLOAT:
-            drawClip(reinterpret_cast<float const*>(input), m_ImageData->channels(), painter, width, height, FLOAT_CLIP,
-                     scaleSize(1));
+            m_NumClipped = drawClip(reinterpret_cast<float const*>(input), m_ImageData->channels(), painter, width, height, FLOAT_CLIP,
+                                    scaleSize(1));
             break;
         case TLONGLONG:
-            drawClip(reinterpret_cast<long long const*>(input), m_ImageData->channels(), painter, width, height, USHORT_CLIP,
-                     scaleSize(1));
+            m_NumClipped = drawClip(reinterpret_cast<long long const*>(input), m_ImageData->channels(), painter, width, height,
+                                    USHORT_CLIP,
+                                    scaleSize(1));
             break;
         case TDOUBLE:
-            drawClip(reinterpret_cast<double const*>(input), m_ImageData->channels(), painter, width, height, FLOAT_CLIP,
-                     scaleSize(1));
+            m_NumClipped = drawClip(reinterpret_cast<double const*>(input), m_ImageData->channels(), painter, width, height, FLOAT_CLIP,
+                                    scaleSize(1));
             break;
         default:
+            m_NumClipped = 0;
             break;
     }
+    emit newStatus(QString("Clip:%1").arg(m_NumClipped), FITS_CLIP);
+
 }
 
 void FITSView::ZoomDefault()
@@ -974,6 +1011,7 @@ void FITSView::drawOverlay(QPainter * painter, double scale)
 
     if (showMagnifyingGlass)
         drawMagnifyingGlass(painter, scale);
+
 }
 
 // Draws a 100% resolution image rectangle around the mouse position.
@@ -1311,7 +1349,6 @@ void FITSView::drawPixelGrid(QPainter * painter, double scale)
         painter->drawLine(0, cY - y, width, cY - y);
     }
 }
-
 bool FITSView::imageHasWCS()
 {
     if (m_ImageData != nullptr)
@@ -1625,6 +1662,59 @@ void FITSView::resizeTrackingBox(int newSize)
     setTrackingBox(QRect( x - delta, y - delta, newSize, newSize));
 }
 
+void FITSView::processRectangleFixed(int s)
+{
+    int w = m_ImageData->width();
+    int h = m_ImageData->height();
+
+    QPoint c = selectionRectangleRaw.center();
+    c.setX(qMax((int)round(s / 2.0), c.x()));
+    c.setX(qMin(w - (int)round(s / 2.0), c.x()));
+    c.setY(qMax((int)round(s / 2.0), c.y()));
+    c.setY(qMin(h - (int)round(s / 2.0), c.y()));
+
+    QPoint topLeft, botRight;
+    topLeft = QPoint(c.x() - round(s / 2.0), c.y() - round(s / 2.0));
+    botRight = QPoint(c.x() + round(s / 2.0), c.y() + round(s / 2.0));
+
+    emit setRubberBand(QRect(topLeft, botRight));
+    processRectangle(topLeft, botRight, true);
+}
+
+void FITSView::processRectangle(QPoint p1, QPoint p2, bool calculate)
+{
+    if(!isSelectionRectShown())
+        return;
+    //the user can draw a rectangle by dragging the mouse to any direction
+    //but we need to feed Rectangle(topleft, topright)
+    //hence we calculate topleft and topright for each case
+
+    //p1 is the the point where the user presses the mouse
+    //p2 is the point where the user releases the mouse
+    selectionRectangleRaw = QRect(p1, p2).normalized();
+    //Index out of bounds Check for raw Rectangle, this effectively works when user does shift + drag, other wise becomes redundant
+
+    QPoint topLeft = selectionRectangleRaw.topLeft();
+    QPoint botRight = selectionRectangleRaw.bottomRight();
+
+    topLeft.setX(qMax(1, topLeft.x()));
+    topLeft.setY(qMax(1, topLeft.y()));
+    botRight.setX(qMin((int)m_ImageData->width(), botRight.x()));
+    botRight.setY(qMin((int)m_ImageData->height(), botRight.y()));
+
+    selectionRectangleRaw.setTopLeft(topLeft);
+    selectionRectangleRaw.setBottomRight(botRight);
+
+    if(calculate)
+    {
+        emit rectangleUpdated(selectionRectangleRaw);
+    }
+    //updateFrameRoi();
+
+    //emit raw rectangle for calculation
+    //update the stats pane after calculation; there should be ample time for calculation before showing the values
+}
+
 bool FITSView::isImageStretched()
 {
     return stretchImage;
@@ -1645,6 +1735,10 @@ bool FITSView::isEQGridShown()
     return showEQGrid;
 }
 
+bool FITSView::isSelectionRectShown()
+{
+    return showSelectionRect;
+}
 bool FITSView::areObjectsShown()
 {
     return showObjects;
@@ -1682,6 +1776,14 @@ void FITSView::toggleEQGrid()
         updateFrame();
 }
 
+void FITSView::toggleSelectionMode()
+{
+    showSelectionRect = !showSelectionRect;
+    emit showRubberBand(showSelectionRect);
+    if (m_ImageFrame)
+        updateFrame();
+
+}
 void FITSView::toggleObjects()
 {
     showObjects = !showObjects;
@@ -1902,7 +2004,11 @@ void FITSView::wheelEvent(QWheelEvent * event)
     }
     else
     {
+#if QT_VERSION < QT_VERSION_CHECK(5, 14, 0)
         QPoint mouseCenter = getImagePoint(event->pos());
+#else
+        QPoint mouseCenter = getImagePoint(event->position().toPoint());
+#endif
         if (event->angleDelta().y() > 0)
             ZoomIn();
         else
@@ -1910,6 +2016,7 @@ void FITSView::wheelEvent(QWheelEvent * event)
         event->accept();
         cleanUpZoom(mouseCenter);
     }
+    emit zoomRubberBand(getCurrentZoom() / ZOOM_DEFAULT);
 }
 
 /**
