@@ -85,6 +85,7 @@ FITSViewer::FITSViewer(QWidget *parent) : KXmlGuiWindow(parent)
 
     fitsWCS.setVisible(false);
 
+    statusBar()->insertPermanentWidget(FITS_CLIP, &fitsClip);
     statusBar()->insertPermanentWidget(FITS_HFR, &fitsHFR);
     statusBar()->insertPermanentWidget(FITS_WCS, &fitsWCS);
     statusBar()->insertPermanentWidget(FITS_VALUE, &fitsValue);
@@ -169,6 +170,41 @@ FITSViewer::FITSViewer(QWidget *parent) : KXmlGuiWindow(parent)
     action->setText(i18n("Statistics"));
     connect(action, SIGNAL(triggered(bool)), SLOT(statFITS()));
 
+    action = actionCollection()->addAction("image_roi_stats");
+
+    roiActionMenu = new KActionMenu(QIcon(":/icons/select_stat"), "Selection Statistics", action );
+    roiActionMenu->setText(i18n("&Selection Statistics"));
+    roiActionMenu->setDelayed(false);
+    roiActionMenu->addSeparator();
+    connect(roiActionMenu, &QAction::triggered, this, &FITSViewer::toggleSelectionMode);
+
+    KToggleAction *ksa = actionCollection()->add<KToggleAction>("100x100");
+    ksa->setText("100x100");
+    ksa->setCheckable(false);
+    roiActionMenu->addAction(ksa);
+    ksa = actionCollection()->add<KToggleAction>("50x50");
+    ksa->setText("50x50");
+    ksa->setCheckable(false);
+    roiActionMenu->addAction(ksa);
+    ksa = actionCollection()->add<KToggleAction>("25x25");
+    ksa->setText("25x25");
+    ksa->setCheckable(false);
+    roiActionMenu->addAction(ksa);
+    ksa = actionCollection()->add<KToggleAction>("CustomRoi");
+    ksa->setText("Custom");
+    ksa->setCheckable(false);
+    roiActionMenu->addAction(ksa);
+
+    action->setMenu(roiActionMenu->menu());
+    action->setIcon(QIcon(":/icons/select_stat"));
+    action->setCheckable(true);
+
+    connect(roiActionMenu->menu()->actions().at(1), &QAction::triggered, this, [this] { ROIFixedSize(100); });
+    connect(roiActionMenu->menu()->actions().at(2), &QAction::triggered, this, [this] { ROIFixedSize(50); });
+    connect(roiActionMenu->menu()->actions().at(3), &QAction::triggered, this, [this] { ROIFixedSize(25); });
+    connect(roiActionMenu->menu()->actions().at(4), &QAction::triggered, this, [this] { customROIInputWindow();});
+    connect(action, &QAction::triggered, this, &FITSViewer::toggleSelectionMode);
+
     action = actionCollection()->addAction("view_crosshair");
     action->setIcon(QIcon::fromTheme("crosshairs"));
     action->setText(i18n("Show Cross Hairs"));
@@ -236,6 +272,7 @@ FITSViewer::FITSViewer(QWidget *parent) : KXmlGuiWindow(parent)
         filterCounter++;
     }
 
+    this->setAttribute(Qt::WA_AlwaysShowToolTips);
     /* Create GUI */
     createGUI("fitsviewerui.rc");
 
@@ -333,16 +370,23 @@ QString HFRStatusString(const QSharedPointer<FITSData> &data)
     if (hfrValue <= 0.0) return QString("");
     if (data->getSkyBackground().starsDetected > 0)
         return
-            i18np("HFR=%2 Ecc=%3 %1 star.", "HFR=%2 Ecc=%3 %1 stars.",
+            i18np("HFR:%2 Ecc:%3 %1 star.", "HFR:%2 Ecc:%3 %1 stars.",
                   data->getSkyBackground().starsDetected,
                   QString::number(hfrValue, 'f', 2),
                   QString::number(data->getEccentricity(), 'f', 2));
     else
         return
-            i18np("HFR=%2, %1 star.", "HFR=%2, %1 stars.",
+            i18np("HFR:%2, %1 star.", "HFR:%2, %1 stars.",
                   data->getDetectedStars(),
                   QString::number(hfrValue, 'f', 2));
 }
+
+QString HFRClipString(FITSView* view)
+{
+    if (view->isClippingShown())
+        return QString("Clip:%1").arg(view->getNumClipped());
+    return "";
+}
 }  // namespace
 
 bool FITSViewer::addFITSCommon(FITSTab *tab, const QUrl &imageName,
@@ -363,9 +407,9 @@ bool FITSViewer::addFITSCommon(FITSTab *tab, const QUrl &imageName,
     connect(tab, &FITSTab::changeStatus, this, &FITSViewer::updateTabStatus);
     connect(tab, &FITSTab::debayerToggled, this, &FITSViewer::setDebayerAction);
     // Connect tab view signals
-    connect(tab->getView(), &FITSView::actionUpdated, this, &FITSViewer::updateAction);
-    connect(tab->getView(), &FITSView::wcsToggled, this, &FITSViewer::updateWCSFunctions);
-    connect(tab->getView(), &FITSView::starProfileWindowClosed, this, &FITSViewer::starProfileButtonOff);
+    connect(tab->getView().get(), &FITSView::actionUpdated, this, &FITSViewer::updateAction);
+    connect(tab->getView().get(), &FITSView::wcsToggled, this, &FITSViewer::updateWCSFunctions);
+    connect(tab->getView().get(), &FITSView::starProfileWindowClosed, this, &FITSViewer::starProfileButtonOff);
 
     switch (mode)
     {
@@ -388,6 +432,9 @@ bool FITSViewer::addFITSCommon(FITSTab *tab, const QUrl &imageName,
         case FITS_ALIGN:
             fitsTabWidget->addTab(tab, i18n("Align"));
             break;
+
+        case FITS_UNKNOWN:
+            break;
     }
 
     saveFileAction->setEnabled(true);
@@ -415,6 +462,8 @@ bool FITSViewer::addFITSCommon(FITSTab *tab, const QUrl &imageName,
         updateStatusBar("", FITS_HFR);
     updateStatusBar(i18n("Ready."), FITS_MESSAGE);
 
+    updateStatusBar(HFRClipString(tab->getView().get()), FITS_CLIP);
+
     tab->getView()->setCursorMode(FITSView::dragCursor);
 
     updateWCSFunctions();
@@ -422,14 +471,14 @@ bool FITSViewer::addFITSCommon(FITSTab *tab, const QUrl &imageName,
     return true;
 }
 
-void FITSViewer::loadFile(const QUrl &imageName, FITSMode mode, FITSScale filter, const QString &previewText, bool silent)
+void FITSViewer::loadFile(const QUrl &imageName, FITSMode mode, FITSScale filter, const QString &previewText)
 {
     led.setColor(Qt::yellow);
     QApplication::setOverrideCursor(Qt::WaitCursor);
 
     FITSTab *tab = new FITSTab(this);
 
-    connect(tab, &FITSTab::failed, [&]()
+    connect(tab, &FITSTab::failed, this, [&](const QString & errorMessage)
     {
         QApplication::restoreOverrideCursor();
         led.setColor(Qt::red);
@@ -439,16 +488,16 @@ void FITSViewer::loadFile(const QUrl &imageName, FITSMode mode, FITSScale filter
             close();
         }
 
-        emit failed();
+        emit failed(errorMessage);
     });
 
-    connect(tab, &FITSTab::loaded, [ = ]()
+    connect(tab, &FITSTab::loaded, this, [ = ]()
     {
         if (addFITSCommon(tab, imageName, mode, previewText))
             emit loaded(fitsID++);
     });
 
-    tab->loadFile(imageName, mode, filter, silent);
+    tab->loadFile(imageName, mode, filter);
 }
 
 bool FITSViewer::loadData(const QSharedPointer<FITSData> &data, const QUrl &imageName, int *tab_uid, FITSMode mode,
@@ -461,6 +510,7 @@ bool FITSViewer::loadData(const QSharedPointer<FITSData> &data, const QUrl &imag
 
     if (!tab->loadData(data, mode, filter))
     {
+        auto errorMessage = tab->getView()->imageData()->getLastError();
         QApplication::restoreOverrideCursor();
         led.setColor(Qt::red);
         if (fitsTabs.size() == 0)
@@ -468,7 +518,7 @@ bool FITSViewer::loadData(const QSharedPointer<FITSData> &data, const QUrl &imag
             // Close FITS Viewer and let KStars know it is no longer needed in memory.
             close();
         }
-        emit failed();
+        emit failed(errorMessage);
         return false;
     }
 
@@ -500,14 +550,14 @@ bool FITSViewer::removeFITS(int fitsUID)
     return false;
 }
 
-void FITSViewer::updateFile(const QUrl &imageName, int fitsUID, FITSScale filter, bool silent)
+void FITSViewer::updateFile(const QUrl &imageName, int fitsUID, FITSScale filter)
 {
     FITSTab *tab = fitsMap.value(fitsUID);
 
     if (tab == nullptr)
     {
-        qCWarning(KSTARS_FITS) << "Cannot find tab with UID " << fitsUID << " in the FITS Viewer";
-        emit failed();
+        QString message = i18n("Cannot find tab with UID %1 in the FITS Viewer", fitsUID);
+        emit failed(message);
         return;
     }
 
@@ -525,7 +575,7 @@ void FITSViewer::updateFile(const QUrl &imageName, int fitsUID, FITSScale filter
         }
     });
 
-    tab->loadFile(imageName, tab->getView()->getMode(), filter, silent);
+    tab->loadFile(imageName, tab->getView()->getMode(), filter);
 }
 
 bool FITSViewer::updateFITSCommon(FITSTab *tab, const QUrl &imageName)
@@ -556,6 +606,8 @@ bool FITSViewer::updateFITSCommon(FITSTab *tab, const QUrl &imageName)
     else
         updateStatusBar("", FITS_HFR);
 
+    updateStatusBar(HFRClipString(tab->getView().get()), FITS_CLIP);
+
     return true;
 }
 
@@ -590,7 +642,7 @@ void FITSViewer::tabFocusUpdated(int currentIndex)
 
     fitsTabs[currentIndex]->tabPositionUpdated();
 
-    FITSView *view = fitsTabs[currentIndex]->getView();
+    auto view = fitsTabs[currentIndex]->getView();
 
     view->toggleStars(markStars);
 
@@ -602,6 +654,8 @@ void FITSViewer::tabFocusUpdated(int currentIndex)
     else
         updateStatusBar("", FITS_HFR);
 
+    updateStatusBar(HFRClipString(fitsTabs[currentIndex]->getView().get()), FITS_CLIP);
+
     if (view->imageData()->hasDebayer())
     {
         actionCollection()->action("fits_debayer")->setEnabled(true);
@@ -617,13 +671,17 @@ void FITSViewer::tabFocusUpdated(int currentIndex)
         actionCollection()->action("fits_debayer")->setEnabled(false);
 
     updateStatusBar("", FITS_WCS);
-    connect(view, &FITSView::starProfileWindowClosed, this, &FITSViewer::starProfileButtonOff);
-    updateButtonStatus("toggle_3D_graph", i18n("View 3D Graph"), getCurrentView()->isStarProfileShown());
-    updateButtonStatus("view_crosshair", i18n("Cross Hairs"), getCurrentView()->isCrosshairShown());
-    updateButtonStatus("view_clipping", i18n("Clipping"), getCurrentView()->isClippingShown());
-    updateButtonStatus("view_eq_grid", i18n("Equatorial Gridines"), getCurrentView()->isEQGridShown());
-    updateButtonStatus("view_objects", i18n("Objects in Image"), getCurrentView()->areObjectsShown());
-    updateButtonStatus("view_pixel_grid", i18n("Pixel Gridlines"), getCurrentView()->isPixelGridShown());
+    connect(view.get(), &FITSView::starProfileWindowClosed, this, &FITSViewer::starProfileButtonOff);
+    QSharedPointer<FITSView> currentView;
+    if (getCurrentView(currentView))
+    {
+        updateButtonStatus("toggle_3D_graph", i18n("currentView 3D Graph"), currentView->isStarProfileShown());
+        updateButtonStatus("currentView_crosshair", i18n("Cross Hairs"), currentView->isCrosshairShown());
+        updateButtonStatus("currentView_clipping", i18n("Clipping"), currentView->isClippingShown());
+        updateButtonStatus("currentView_eq_grid", i18n("Equatorial Gridines"), currentView->isEQGridShown());
+        updateButtonStatus("currentView_objects", i18n("Objects in Image"), currentView->areObjectsShown());
+        updateButtonStatus("currentView_pixel_grid", i18n("Pixel Gridlines"), currentView->isPixelGridShown());
+    }
 
     updateScopeButton();
     updateWCSFunctions();
@@ -659,7 +717,7 @@ void FITSViewer::openFile()
         }
     }
 
-    loadFile(fileURL, FITS_NORMAL, FITS_NONE, QString(), false);
+    loadFile(fileURL, FITS_NORMAL, FITS_NONE, QString());
 }
 
 void FITSViewer::saveFile()
@@ -737,16 +795,14 @@ void FITSViewer::debayerFITS()
         debayerDialog = new FITSDebayer(this);
     }
 
-    FITSView *view = getCurrentView();
-
-    if (view == nullptr)
-        return;
-
-    BayerParams param;
-    view->imageData()->getBayerParams(&param);
-    debayerDialog->setBayerParams(&param);
-
-    debayerDialog->show();
+    QSharedPointer<FITSView> view;
+    if (getCurrentView(view))
+    {
+        BayerParams param;
+        view->imageData()->getBayerParams(&param);
+        debayerDialog->setBayerParams(&param);
+        debayerDialog->show();
+    }
 }
 
 void FITSViewer::updateStatusBar(const QString &msg, FITSBar id)
@@ -772,6 +828,9 @@ void FITSViewer::updateStatusBar(const QString &msg, FITSBar id)
         case FITS_HFR:
             fitsHFR.setText(msg);
             break;
+        case FITS_CLIP:
+            fitsClip.setText(msg);
+            break;
         case FITS_MESSAGE:
             statusBar()->showMessage(msg);
             break;
@@ -810,7 +869,9 @@ void FITSViewer::ZoomToFit()
     if (fitsTabs.empty())
         return;
 
-    getCurrentView()->ZoomToFit();
+    QSharedPointer<FITSView> currentView;
+    if (getCurrentView(currentView))
+        currentView->ZoomToFit();
 }
 
 void FITSViewer::updateAction(const QString &name, bool enable)
@@ -888,16 +949,17 @@ This is a method that either enables or disables the WCS based features in the C
 
 void FITSViewer::updateWCSFunctions()
 {
-    if (getCurrentView() == nullptr)
+    QSharedPointer<FITSView> currentView;
+    if (!getCurrentView(currentView))
         return;
 
-    if (getCurrentView()->imageHasWCS())
+    if (currentView->imageHasWCS())
     {
         actionCollection()->action("view_eq_grid")->setDisabled(false);
         actionCollection()->action("view_eq_grid")->setText(i18n("Show Equatorial Gridlines"));
         actionCollection()->action("view_objects")->setDisabled(false);
         actionCollection()->action("view_objects")->setText(i18n("Show Objects in Image"));
-        if (getCurrentView()->isTelescopeActive())
+        if (currentView->isTelescopeActive())
         {
             actionCollection()->action("center_telescope")->setDisabled(false);
 
@@ -922,7 +984,11 @@ void FITSViewer::updateWCSFunctions()
 
 void FITSViewer::updateScopeButton()
 {
-    if (getCurrentView()->getCursorMode() == FITSView::scopeCursor)
+    QSharedPointer<FITSView> currentView;
+    if (!getCurrentView(currentView))
+        return;
+
+    if (currentView->getCursorMode() == FITSView::scopeCursor)
     {
         actionCollection()->action("center_telescope")->setChecked(true);
     }
@@ -932,6 +998,85 @@ void FITSViewer::updateScopeButton()
     }
 }
 
+void FITSViewer::ROIFixedSize(int s)
+{
+    if (fitsTabs.empty())
+        return;
+
+    QSharedPointer<FITSView> currentView;
+    if (getCurrentView(currentView))
+    {
+        if(!currentView->isSelectionRectShown())
+        {
+            toggleSelectionMode();
+            updateButtonStatus("image_roi_stats", i18n("Selection Rectangle"), currentView->isSelectionRectShown());
+        }
+        currentView->processRectangleFixed(s);
+    }
+}
+
+void FITSViewer::customROIInputWindow()
+{
+    if(fitsTabs.empty())
+        return;
+
+    QSharedPointer<FITSView> currentView;
+    if (getCurrentView(currentView))
+    {
+        if(!currentView->isSelectionRectShown())
+            return;
+
+        int mh = currentView->imageData()->height();
+        int mw = currentView->imageData()->width();
+
+        if(mh % 2)
+            mh++;
+        if(mw % 2)
+            mw++;
+
+        QDialog customRoiDialog;
+        QFormLayout form(&customRoiDialog);
+        QDialogButtonBox buttonBox(QDialogButtonBox:: Ok | QDialogButtonBox:: Cancel, Qt::Horizontal, &customRoiDialog);
+
+        form.addRow(new QLabel(i18n("Size")));
+
+        QLineEdit wle(&customRoiDialog);
+        QLineEdit hle(&customRoiDialog);
+
+        wle.setValidator(new QIntValidator(1, mw, &wle));
+        hle.setValidator(new QIntValidator(1, mh, &hle));
+
+        form.addRow(i18n("Width"), &wle);
+        form.addRow(i18n("Height"), &hle);
+        form.addRow(&buttonBox);
+
+        connect(&buttonBox, &QDialogButtonBox::accepted, &customRoiDialog, &QDialog::accept);
+        connect(&buttonBox, &QDialogButtonBox::rejected, &customRoiDialog, &QDialog::reject);
+
+        if(customRoiDialog.exec() == QDialog::Accepted)
+        {
+            QPoint resetCenter = currentView->getSelectionRegion().center();
+            int newheight = hle.text().toInt();
+            int newwidth = wle.text().toInt();
+
+            newheight = qMin(newheight, mh) ;
+            newheight = qMax(newheight, 1) ;
+            newwidth = qMin(newwidth, mw);
+            newwidth = qMax(newwidth, 1);
+
+            QPoint topLeft = resetCenter;
+            QPoint botRight = resetCenter;
+
+            topLeft.setX((topLeft.x() - newwidth / 2));
+            topLeft.setY((topLeft.y() - newheight / 2));
+            botRight.setX((botRight.x() + newwidth / 2));
+            botRight.setY((botRight.y() + newheight / 2));
+
+            emit currentView->setRubberBand(QRect(topLeft, botRight));
+            currentView->processRectangle(topLeft, botRight, true);
+        }
+    }
+}
 /**
  This method either enables or disables the scope mouse mode so you can slew your scope to coordinates
  just by clicking the mouse on a spot in the image.
@@ -939,15 +1084,19 @@ void FITSViewer::updateScopeButton()
 
 void FITSViewer::centerTelescope()
 {
-    getCurrentView()->setScopeButton(actionCollection()->action("center_telescope"));
-    if (getCurrentView()->getCursorMode() == FITSView::scopeCursor)
+    QSharedPointer<FITSView> currentView;
+    if (!getCurrentView(currentView))
+        return;
+
+    currentView->setScopeButton(actionCollection()->action("center_telescope"));
+    if (currentView->getCursorMode() == FITSView::scopeCursor)
     {
-        getCurrentView()->setCursorMode(getCurrentView()->lastMouseMode);
+        currentView->setCursorMode(currentView->lastMouseMode);
     }
     else
     {
-        getCurrentView()->lastMouseMode = getCurrentView()->getCursorMode();
-        getCurrentView()->setCursorMode(FITSView::scopeCursor);
+        currentView->lastMouseMode = currentView->getCursorMode();
+        currentView->setCursorMode(FITSView::scopeCursor);
     }
     updateScopeButton();
 }
@@ -956,48 +1105,92 @@ void FITSViewer::toggleCrossHair()
 {
     if (fitsTabs.empty())
         return;
-    getCurrentView()->toggleCrosshair();
-    updateButtonStatus("view_crosshair", i18n("Cross Hairs"), getCurrentView()->isCrosshairShown());
+
+    QSharedPointer<FITSView> currentView;
+    if (!getCurrentView(currentView))
+        return;
+
+    currentView->toggleCrosshair();
+    updateButtonStatus("view_crosshair", i18n("Cross Hairs"), currentView->isCrosshairShown());
 }
 
 void FITSViewer::toggleClipping()
 {
     if (fitsTabs.empty())
         return;
-    getCurrentView()->toggleClipping();
-    updateButtonStatus("view_clipping", i18n("Clipping"), getCurrentView()->isClippingShown());
+
+    QSharedPointer<FITSView> currentView;
+    if (!getCurrentView(currentView))
+        return;
+    currentView->toggleClipping();
+    if (!currentView->isClippingShown())
+        fitsClip.clear();
+    updateButtonStatus("view_clipping", i18n("Clipping"), currentView->isClippingShown());
 }
 
 void FITSViewer::toggleEQGrid()
 {
     if (fitsTabs.empty())
         return;
-    getCurrentView()->toggleEQGrid();
-    updateButtonStatus("view_eq_grid", i18n("Equatorial Gridlines"), getCurrentView()->isEQGridShown());
+
+    QSharedPointer<FITSView> currentView;
+    if (!getCurrentView(currentView))
+        return;
+
+    currentView->toggleEQGrid();
+    updateButtonStatus("view_eq_grid", i18n("Equatorial Gridlines"), currentView->isEQGridShown());
+}
+
+void FITSViewer::toggleSelectionMode()
+{
+    if (fitsTabs.empty())
+        return;
+
+    QSharedPointer<FITSView> currentView;
+    if (!getCurrentView(currentView))
+        return;
+
+    currentView->toggleSelectionMode();
+    updateButtonStatus("image_roi_stats", i18n("Selection Rectangle"), currentView->isSelectionRectShown());
 }
 
 void FITSViewer::toggleObjects()
 {
     if (fitsTabs.empty())
         return;
-    getCurrentView()->toggleObjects();
-    updateButtonStatus("view_objects", i18n("Objects in Image"), getCurrentView()->areObjectsShown());
+
+    QSharedPointer<FITSView> currentView;
+    if (!getCurrentView(currentView))
+        return;
+
+    currentView->toggleObjects();
+    updateButtonStatus("view_objects", i18n("Objects in Image"), currentView->areObjectsShown());
 }
 
 void FITSViewer::togglePixelGrid()
 {
     if (fitsTabs.empty())
         return;
-    getCurrentView()->togglePixelGrid();
-    updateButtonStatus("view_pixel_grid", i18n("Pixel Gridlines"), getCurrentView()->isPixelGridShown());
+
+    QSharedPointer<FITSView> currentView;
+    if (!getCurrentView(currentView))
+        return;
+
+    currentView->togglePixelGrid();
+    updateButtonStatus("view_pixel_grid", i18n("Pixel Gridlines"), currentView->isPixelGridShown());
 }
 
 void FITSViewer::toggle3DGraph()
 {
     if (fitsTabs.empty())
         return;
-    getCurrentView()->toggleStarProfile();
-    updateButtonStatus("toggle_3D_graph", i18n("View 3D Graph"), getCurrentView()->isStarProfileShown());
+
+    QSharedPointer<FITSView> currentView;
+    if (!getCurrentView(currentView))
+        return;
+
+    currentView->toggleStarProfile();
+    updateButtonStatus("toggle_3D_graph", i18n("View 3D Graph"), currentView->isStarProfileShown());
 }
 
 void FITSViewer::toggleStars()
@@ -1035,22 +1228,25 @@ void FITSViewer::applyFilter(int ftype)
     updateStatusBar(i18n("Ready."), FITS_MESSAGE);
 }
 
-FITSView *FITSViewer::getView(int fitsUID)
+bool FITSViewer::getView(int fitsUID, QSharedPointer<FITSView> &view)
 {
     FITSTab *tab = fitsMap.value(fitsUID);
-
     if (tab)
-        return tab->getView();
+    {
+        view = tab->getView();
+        return true;
+    }
+    return false;
 
-    return nullptr;
 }
 
-FITSView *FITSViewer::getCurrentView()
+bool FITSViewer::getCurrentView(QSharedPointer<FITSView> &view)
 {
     if (fitsTabs.empty() || fitsTabWidget->currentIndex() >= fitsTabs.count())
-        return nullptr;
+        return false;
 
-    return fitsTabs[fitsTabWidget->currentIndex()]->getView();
+    view = fitsTabs[fitsTabWidget->currentIndex()]->getView();
+    return true;
 }
 
 void FITSViewer::setDebayerAction(bool enable)
