@@ -211,7 +211,8 @@ typedef enum
     INDI_SET_FILTER_NAMES,
     INDI_CONFIRM_FILTER,
     INDI_SET_ROTATOR_TICKS,
-    INDI_SET_ROTATOR_ANGLE
+    INDI_SET_ROTATOR_ANGLE,
+    INDI_REVERSE_ROTATOR
 } DeviceCommand;
 
 typedef enum { SOURCE_MANUAL, SOURCE_FLATCAP, SOURCE_WALL, SOURCE_DAWN_DUSK, SOURCE_DARKCAP } FlatFieldSource;
