@@ -23,11 +23,15 @@
 
 #include <indi_debug.h>
 
+// Qt version calming
+#include <qtendl.h>
+
 namespace ISD
 {
 
-const QList<const char *> Telescope::mountStates = { I18N_NOOP("Idle"),  I18N_NOOP("Parked"),  I18N_NOOP("Parking"),
-                                                     I18N_NOOP("Slewing"), I18N_NOOP("Moving"), I18N_NOOP("Tracking"), I18N_NOOP("Error")
+const QList<const char *> Telescope::mountStates = { I18N_NOOP("Idle"),  I18N_NOOP("Moving"), I18N_NOOP("Slewing"),
+                                                     I18N_NOOP("Tracking"), I18N_NOOP("Parking"), I18N_NOOP("Parked"),
+                                                     I18N_NOOP("Error")
                                                    };
 
 Telescope::Telescope(GDInterface *iPtr) : DeviceDecorator(iPtr)
@@ -448,6 +452,11 @@ void Telescope::processSwitch(ISwitchVectorProperty *svp)
         manualMotionChanged = true;
     else if (!strcmp(svp->name, "TELESCOPE_MOTION_WE"))
         manualMotionChanged = true;
+    else if (!strcmp(svp->name, "TELESCOPE_REVERSE_MOTION"))
+    {
+        emit axisReversed(AXIS_DE, svp->sp[0].s == ISS_ON);
+        emit axisReversed(AXIS_RA, svp->sp[1].s == ISS_ON);
+    }
 
     if (manualMotionChanged)
     {
@@ -608,14 +617,14 @@ bool Telescope::doPulse(GuideDirection dir, int msecs)
 
     clientManager->sendNewNumber(npulse);
 
-    //qDebug() << "Sending pulse for " << npulse->getName() << " in direction " << dirPulse->getName() << " for " << msecs << " ms " << endl;
+    //qDebug() << Q_FUNC_INFO << "Sending pulse for " << npulse->getName() << " in direction " << dirPulse->getName() << " for " << msecs << " ms " << Qt::endl;
 
     return true;
 }
 
 bool Telescope::runCommand(int command, void *ptr)
 {
-    //qDebug() << "Telescope run command is called!!!" << endl;
+    //qDebug() << Q_FUNC_INFO << "Telescope run command is called!!!" << Qt::endl;
 
     switch (command)
     {
@@ -708,7 +717,7 @@ bool Telescope::sendCoords(SkyPoint *ScopeTarget)
     if (HorProp && HorProp->getPermission() == IP_RO)
         HorProp = nullptr;
 
-    //qDebug() << "Skymap click - RA: " << scope_target->ra().toHMSString() << " DEC: " << scope_target->dec().toDMSString();
+    //qDebug() << Q_FUNC_INFO << "Skymap click - RA: " << scope_target->ra().toHMSString() << " DEC: " << scope_target->dec().toDMSString();
 
     if (EqProp)
     {
@@ -814,7 +823,8 @@ bool Telescope::sendCoords(SkyPoint *ScopeTarget)
     // for the target coordinates) calls sendToMountDevice
     auto checkObjectAndSend = [ = ]()
     {
-        double maxrad = 1000.0 / Options::zoomFactor();
+        // Search within 0.1 degrees indepdent of zoom level.
+        double maxrad = 0.1;
         currentObject = KStarsData::Instance()->skyComposite()->objectNearest(ScopeTarget, maxrad);
         if (currentObject)
         {
@@ -1029,7 +1039,7 @@ bool Telescope::Abort()
     if (!abortSW)
         return false;
 
-    qCDebug(KSTARS_INDI) << "ISD:Telescope: Aborted." << endl;
+    qCDebug(KSTARS_INDI) << "ISD:Telescope: Aborted." << Qt::endl;
 
     abortSW->setState(ISS_ON);
     clientManager->sendNewSwitch(motionSP);
@@ -1051,7 +1061,7 @@ bool Telescope::Park()
     if (!parkSW)
         return false;
 
-    qCDebug(KSTARS_INDI) << "ISD:Telescope: Parking..." << endl;
+    qCDebug(KSTARS_INDI) << "ISD:Telescope: Parking..." << Qt::endl;
 
     parkSP->reset();
     parkSW->setState(ISS_ON);
@@ -1072,7 +1082,7 @@ bool Telescope::UnPark()
     if (!parkSW)
         return false;
 
-    qCDebug(KSTARS_INDI) << "ISD:Telescope: UnParking..." << endl;
+    qCDebug(KSTARS_INDI) << "ISD:Telescope: UnParking..." << Qt::endl;
 
     parkSP->reset();
     parkSW->setState(ISS_ON);
@@ -1575,6 +1585,13 @@ bool Telescope::setReversedEnabled(INDI_EQ_AXIS axis, bool enabled)
     return true;
 }
 
+void Telescope::stopTimers()
+{
+    updateCoordinatesTimer.stop();
+    centerLockTimer.stop();
+    readyTimer.stop();
+}
+
 }
 
 QDBusArgument &operator<<(QDBusArgument &argument, const ISD::Telescope::Status &source)
