@@ -205,6 +205,11 @@ class Telescope : public DeviceDecorator
             return currentCoords;
         }
 
+        /**
+         * @brief stopTimers Stop timers to prevent timing race condition when device is unavailable
+         * and timer is still invoked.
+         */
+        void stopTimers();
 
     protected:
         /**
@@ -266,6 +271,7 @@ class Telescope : public DeviceDecorator
         void newParkStatus(ISD::ParkStatus status);
         void slewRateChanged(int rate);
         void pierSideChanged(PierSide side);
+        void axisReversed(INDI_EQ_AXIS axis, bool reversed);
         void ready();
 
     private:
