@@ -85,15 +85,15 @@ QString riseSetTimeLabel(SkyObject *o, bool isRaise)
         //We can round to the nearest minute by simply adding 30 seconds to the time.
         QString time = QLocale().toString(t.addSecs(30), QLocale::ShortFormat);
         return isRaise ? i18n("Rise time: %1", time) :
-                         i18nc("the time at which an object falls below the horizon",
-                               "Set time: %1", time);
+               i18nc("the time at which an object falls below the horizon",
+                     "Set time: %1", time);
     }
     if (o->alt().Degrees() > 0)
         return isRaise ? i18n("No rise time: Circumpolar") :
-                         i18n("No set time: Circumpolar");
+               i18n("No set time: Circumpolar");
     else
         return isRaise ? i18n("No rise time: Never rises") :
-                         i18n("No set time: Never rises");
+               i18n("No set time: Never rises");
 }
 
 // String representation for transit time for object
@@ -231,8 +231,8 @@ void KSPopupMenu::createCatalogObjectMenu(CatalogObject *obj)
     QString typeName = obj->typeName();
 
     QString info = QString("%1<br>Catalog: %2")
-                       .arg(magToStr(obj->mag()))
-                       .arg(obj->getCatalog().name);
+                   .arg(magToStr(obj->mag()))
+                   .arg(obj->getCatalog().name);
 
     if (obj->a() > 0)
     {
@@ -274,9 +274,9 @@ void KSPopupMenu::createSatelliteMenu(Satellite *satellite)
     addFancyLabel(satellite->id());
     addFancyLabel(i18n("satellite"));
     addFancyLabel(KStarsData::Instance()
-                      ->skyComposite()
-                      ->constellationBoundary()
-                      ->constellationName(satellite));
+                  ->skyComposite()
+                  ->constellationBoundary()
+                  ->constellationName(satellite));
 
     addSeparator();
 
@@ -348,9 +348,9 @@ void KSPopupMenu::initPopupMenu(SkyObject *obj, const QString &name, const QStri
     addFancyLabel(type);
     addFancyLabel(info);
     addFancyLabel(KStarsData::Instance()
-                      ->skyComposite()
-                      ->constellationBoundary()
-                      ->constellationName(obj));
+                  ->skyComposite()
+                  ->constellationBoundary()
+                  ->constellationName(obj));
 
     //Insert Rise/Set/Transit labels
     SkyObject *o = obj->clone();
@@ -434,9 +434,9 @@ void KSPopupMenu::initPopupMenu(SkyObject *obj, const QString &name, const QStri
 
     addSeparator();
     if (obj->isSolarSystem() &&
-        obj->type() !=
+            obj->type() !=
             SkyObject::
-                COMET) // FIXME: We now have asteroids -- so should this not be isMajorPlanet() || Pluto?
+            COMET) // FIXME: We now have asteroids -- so should this not be isMajorPlanet() || Pluto?
     {
         addAction(i18n("View in XPlanet"), map, SLOT(slotStartXplanetViewer()));
     }
@@ -532,10 +532,12 @@ void KSPopupMenu::addLinksToMenu(SkyObject *obj, bool showDSS)
     const auto &user_data    = KStarsData::Instance()->getUserData(obj->name());
     const auto &image_list   = user_data.images();
     const auto &website_list = user_data.websites();
-    for (const auto &res : std::list<
-             std::tuple<QString, SkyObjectUserdata::LinkList, SkyObjectUserdata::Type>>{
-             { i18n("Image Resources"), image_list, SkyObjectUserdata::Type::image },
-             { i18n("Web Links"), website_list, SkyObjectUserdata::Type::website } })
+    for (const auto &res : std::list <
+            std::tuple<QString, SkyObjectUserdata::LinkList, SkyObjectUserdata::Type >>
+{
+    { i18n("Image Resources"), image_list, SkyObjectUserdata::Type::image },
+        { i18n("Web Links"), website_list, SkyObjectUserdata::Type::website }
+    })
     {
         const auto &title = std::get<0>(res);
         const auto &list  = std::get<1>(res);
@@ -574,7 +576,7 @@ void KSPopupMenu::addLinksToMenu(SkyObject *obj, bool showDSS)
             CatalogsDB::DBManager manager{ CatalogsDB::dso_db_path() };
 
             if (object->getCatalog().mut &&
-                manager.get_object(object->getObjectId()).first)
+                    manager.get_object(object->getObjectId()).first)
             {
                 addAction(i18n("Remove From Local Catalog"), ks->map(),
                           SLOT(slotRemoveCustomObject()));
@@ -602,7 +604,7 @@ void KSPopupMenu::addINDI()
     if (INDIListener::Instance()->size() == 0)
         return;
 
-    foreach (ISD::GDInterface *gd, INDIListener::Instance()->getDevices())
+    for (auto oneDevice : INDIListener::Instance()->getDevices())
     {
         INDI::BaseDevice *bd = gd->getBaseDevice();
 
@@ -747,7 +749,7 @@ void KSPopupMenu::addINDI()
 
         const SkyObject *clickedObject = KStars::Instance()->map()->clickedObject();
         if (clickedObject && clickedObject->type() == SkyObject::SATELLITE &&
-            (mount->canTrackSatellite()))
+                (mount->canTrackSatellite()))
         {
             const Satellite *sat = dynamic_cast<const Satellite *>(clickedObject);
             const KStarsDateTime currentTime        = KStarsData::Instance()->ut();
@@ -756,10 +758,11 @@ void KSPopupMenu::addINDI()
                 mountMenu->addAction(QIcon::fromTheme("arrow"), i18n("Track satellite"));
             a->setEnabled(!mount->isParked());
             connect(a, &QAction::triggered,
-                    [mount, sat, currentTime, currentTimePlusOne] {
-                        mount->setSatelliteTLEandTrack(sat->tle(), currentTime,
-                                                       currentTimePlusOne);
-                    });
+                    [mount, sat, currentTime, currentTimePlusOne]
+            {
+                mount->setSatelliteTLEandTrack(sat->tle(), currentTime,
+                                               currentTimePlusOne);
+            });
             mountMenu->addSeparator();
         }
 
