@@ -349,9 +349,13 @@ void KStars::slotINDIToolBar()
         auto scheduler = Ekos::Manager::Instance()->schedulerModule();
         if (a->isChecked() && scheduler && scheduler->status() != Ekos::SCHEDULER_RUNNING)
         {
-            Ekos::FramingAssistantUI *assistant = new Ekos::FramingAssistantUI();
-            assistant->setAttribute(Qt::WA_DeleteOnClose, true);
-            assistant->show();
+            // Only create if we don't have an instance already
+            if (findChild<Ekos::FramingAssistantUI *>("FramingAssistant") == nullptr)
+            {
+                Ekos::FramingAssistantUI *assistant = new Ekos::FramingAssistantUI();
+                assistant->setAttribute(Qt::WA_DeleteOnClose, true);
+                assistant->show();
+            }
         }
     }
 
@@ -1252,15 +1256,13 @@ void KStars::slotOpenFITS()
     path.setUrl(fileURL.url(QUrl::RemoveFilename));
 
     QPointer<FITSViewer> fv = createFITSViewer();
-    //fv.reset(new FITSViewer((Options::independentWindowFITS()) ? nullptr : this));
+    connect(fv, &FITSViewer::failed, [ &, fv](const QString & errorMessage)
+    {
+        KSNotification::error(errorMessage, i18n("Open FITS"), 10);
+        fv->close();
+    });
 
-    //    connect(fv.get(), &FITSViewer::loaded, [ &, fv]()
-    //    {
-    //        addFITSViewer(fv);
-    //        fv->show();
-    //    });
-
-    fv->loadFile(fileURL, FITS_NORMAL, FITS_NONE, QString(), false);
+    fv->loadFile(fileURL, FITS_NORMAL, FITS_NONE, QString());
 #endif
 }
 
@@ -1377,7 +1379,8 @@ void KStars::slotRunScript()
         // FIXME This is a hack and does not work on non-Linux systems
         // The Script Builder should generate files that can run cross-platform
         QProcess p;
-        p.start(f.fileName());
+        QStringList arguments;
+        p.start(f.fileName(), arguments);
         if (!p.waitForStarted())
             return;
 
@@ -1706,7 +1709,7 @@ void KStars::slotColorScheme()
 
 void KStars::slotTargetSymbol(bool flag)
 {
-    qDebug() << QString("slotTargetSymbol: %1 %2").arg(sender()->objectName()).arg(flag);
+    qDebug() << Q_FUNC_INFO << QString("slotTargetSymbol: %1 %2").arg(sender()->objectName()).arg(flag);
 
     QStringList names = Options::fOVNames();
     if (flag)
@@ -1810,7 +1813,7 @@ void KStars::slotEyepieceView(SkyPoint *sp, const QString &imagePath)
         nameToFovMap.insert(i18n("Attempt to determine from image"), nullptr);
         fov = nameToFovMap[QInputDialog::getItem(
                                this, i18n("Eyepiece View: Choose a field-of-view"),
-                               i18n("FOV to render eyepiece view for:"), nameToFovMap.uniqueKeys(), 0, false,
+                               i18n("FOV to render eyepiece view for:"), nameToFovMap.keys(), 0, false,
                                &ok)];
     }
     if (ok)
@@ -1932,9 +1935,19 @@ void KStars::removeColorMenuItem(const QString &actionName)
 
 void KStars::slotAboutToQuit()
 {
+    if (m_SkyMap == nullptr)
+        return;
+
+#ifdef HAVE_INDI
+    DriverManager::Instance()->disconnectClients();
+    INDIListener::Instance()->disconnect();
+    GUIManager::Instance()->disconnect();
+#endif
+
     // Delete skymap. This required to run destructors and save
     // current state in the option.
     delete m_SkyMap;
+    m_SkyMap = nullptr;
 
     //Store Window geometry in Options object
     Options::setWindowWidth(width());
