@@ -680,11 +680,11 @@ void OAL::Log::readTarget()
                 }
             }
             //   else  if( reader->name() == "datasource" )
-            //         qDebug() << reader->readElementText();
+            //         qDebug() << Q_FUNC_INFO << reader->readElementText();
             //     else if( reader->name() == "position" )
             //         readPosition();
             //     else if( reader->name() == "constellation" )
-            //         qDebug() << reader->readElementText();
+            //         qDebug() << Q_FUNC_INFO << reader->readElementText();
             else
                 readUnknownElement();
         }
@@ -787,7 +787,7 @@ SkyPoint OAL::Log::readPosition(bool &OK)
         {
             if (reader->name() == "ra")
             {
-                qDebug() << reader->readElementText() << reader->attributes().value("unit");
+                qDebug() << Q_FUNC_INFO << reader->readElementText() << reader->attributes().value("unit");
                 dms ra;
                 if (reader->attributes().value("unit") == "rad")
                     ra.setRadians(reader->readElementText().toDouble(&RAOK));
@@ -798,7 +798,7 @@ SkyPoint OAL::Log::readPosition(bool &OK)
             }
             else if (reader->name() == "dec")
             {
-                qDebug() << reader->readElementText() << reader->attributes().value("unit");
+                qDebug() << Q_FUNC_INFO << reader->readElementText() << reader->attributes().value("unit");
                 dms de;
                 if (reader->attributes().value("unit") == "rad")
                     de.setRadians(reader->readElementText().toDouble(&DEOK));
