@@ -351,11 +351,11 @@ void SkyMapDrawAbstract::exportSkyImage(SkyQPainter *painter, bool scale)
     if (scale)
     {
         //scale sky image to fit paint device
-        qDebug() << "Scaling true while exporting Sky Image";
+        qDebug() << Q_FUNC_INFO << "Scaling true while exporting Sky Image";
         double xscale = double(painter->device()->width()) / double(m_SkyMap->width());
         double yscale = double(painter->device()->height()) / double(m_SkyMap->height());
         double scale  = qMin(xscale, yscale);
-        qDebug() << "xscale: " << xscale << "yscale: " << yscale << "chosen scale: " << scale;
+        qDebug() << Q_FUNC_INFO << "xscale: " << xscale << "yscale: " << yscale << "chosen scale: " << scale;
         painter->scale(scale, scale);
     }
 
@@ -370,7 +370,7 @@ void SkyMapDrawAbstract::exportSkyImage(SkyQPainter *painter, bool scale)
 {
     if(m_framecount == 25) {
         //float sec = m_fpstime.elapsed()/1000.;
-        // qDebug() << "FPS " << m_framecount/sec;
+        // qDebug() << Q_FUNC_INFO << "FPS " << m_framecount/sec;
         m_framecount = 0;
         m_fpstime.restart();
     }
